'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fabric = require('fabric');
var React = require('react');
var React__default = _interopDefault(React);
var isNaN$1 = _interopDefault(require('lodash/isNaN'));
var pick = _interopDefault(require('lodash/pick'));
var throttle = _interopDefault(require('lodash/throttle'));
var gsap = require('gsap');
var gsap__default = _interopDefault(gsap);
var gifshot = _interopDefault(require('gifshot'));
var ResizeObserver = _interopDefault(require('resize-observer-polyfill'));
var lodash = require('lodash');

var EditorContext = /*#__PURE__*/React.createContext({
  canvas: null,
  setCanvas: function setCanvas() {},
  activeObject: null,
  setActiveObject: function setActiveObject() {},
  editor: null,
  setEditor: function setEditor() {},
  zoomRatio: 1,
  setZoomRatio: function setZoomRatio() {},
  contextMenuRequest: null,
  setContextMenuRequest: function setContextMenuRequest() {}
});
var EditorProvider = function EditorProvider(_ref) {
  var children = _ref.children;

  var _useState = React.useState(null),
      canvas = _useState[0],
      setCanvas = _useState[1];

  var _useState2 = React.useState(null),
      activeObject = _useState2[0],
      setActiveObject = _useState2[1];

  var _useState3 = React.useState(null),
      editor = _useState3[0],
      setEditor = _useState3[1];

  var _useState4 = React.useState(1),
      zoomRatio = _useState4[0],
      setZoomRatio = _useState4[1];

  var _useState5 = React.useState(null),
      contextMenuRequest = _useState5[0],
      setContextMenuRequest = _useState5[1];

  var context = {
    canvas: canvas,
    setCanvas: setCanvas,
    activeObject: activeObject,
    setActiveObject: setActiveObject,
    editor: editor,
    setEditor: setEditor,
    zoomRatio: zoomRatio,
    setZoomRatio: setZoomRatio,
    contextMenuRequest: contextMenuRequest,
    setContextMenuRequest: setContextMenuRequest
  };
  return React__default.createElement(EditorContext.Provider, {
    value: context
  }, children);
};

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;

  _setPrototypeOf(subClass, superClass);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var PROPERTIES_TO_INCLUDE = ['id', 'name', 'description', 'src', 'keys', 'keyValues', 'animation', 'metadata'];
var ObjectType;

(function (ObjectType) {
  ObjectType["STATIC_VECTOR"] = "StaticVector";
  ObjectType["STATIC_GROUP"] = "StaticGroup";
  ObjectType["DYNAMIC_GROUP"] = "DynamicGroup";
  ObjectType["STATIC_PATH"] = "StaticPath";
  ObjectType["DYNAMIC_PATH"] = "DynamicPath";
  ObjectType["STATIC_IMAGE"] = "StaticImage";
  ObjectType["DYNAMIC_IMAGE"] = "DynamicImage";
  ObjectType["STATIC_TEXT"] = "StaticText";
  ObjectType["DYNAMIC_TEXT"] = "DynamicText";
  ObjectType["ACTIVE_SELECTION"] = "activeSelection";
  ObjectType["BACKGROUND"] = "Background";
  ObjectType["GROUP"] = "group";
  ObjectType["FRAME"] = "Frame";
})(ObjectType || (ObjectType = {}));

var ObjectTypeAlt;

(function (ObjectTypeAlt) {
  ObjectTypeAlt["STATIC_IMAGE"] = "image:static";
  ObjectTypeAlt["DYNAMIC_IMAGE"] = "image:dynamic";
  ObjectTypeAlt["TEXTAREA"] = "Textarea";
})(ObjectTypeAlt || (ObjectTypeAlt = {}));

var defaultEditorConfig = {
  clipToFrame: true,
  scrollLimit: 200
};

var getCopyStyleVector = function getCopyStyleVector() {
  var copyStyleVector = "\n  <svg width=\"24\" height=\"24\" viewBox=\"0 0 24 24\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\"><path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M16 3.5H5a.5.5 0 0 0-.5.5v1.5A.5.5 0 0 0 5 6h11a.5.5 0 0 0 .5-.5V4a.5.5 0 0 0-.5-.5zM5 2a2 2 0 0 0-2 2v1.5a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2v-.25h.5a.75.75 0 0 1 .75.75v2.5a.75.75 0 0 1-.75.75h-5.75a2.25 2.25 0 0 0-2.25 2.25v1.563A2 2 0 0 0 9 15v5a2 2 0 0 0 2 2h.5a2 2 0 0 0 2-2v-5a2 2 0 0 0-1.5-1.937V11.5a.75.75 0 0 1 .75-.75h5.75a2.25 2.25 0 0 0 2.25-2.25V6a2.25 2.25 0 0 0-2.25-2.25h-.515A2 2 0 0 0 16 2H5zm7 13a.5.5 0 0 0-.5-.5H11a.5.5 0 0 0-.5.5v5a.5.5 0 0 0 .5.5h.5a.5.5 0 0 0 .5-.5v-5z\" fill=\"currentColor\"></path></svg>\n\t";
  return "data:image/svg+xml;base64," + window.btoa(copyStyleVector);
};

var getCopyStyleCursor = function getCopyStyleCursor() {
  return "url(" + getCopyStyleVector() + "), crosshair";
};
var copyStyleProps = {
  StaticText: ['fill', 'opacity', 'stroke', 'strokeWidth', 'textAlign', 'fontWeight', 'fontFamily', 'fontSize', 'underline', 'shadow', 'angle'],
  DynamicText: ['fill', 'opacity', 'stroke', 'strokeWidth', 'textAlign', 'fontWeight', 'fontFamily', 'fontSize', 'underline', 'shadow', 'angle'],
  StaticImage: ['opacity', 'stroke', 'strokeWidth', 'shadow', 'angle'],
  DynamicImage: ['opacity', 'stroke', 'strokeWidth', 'shadow', 'angle'],
  StaticPath: ['fill', 'opacity', 'stroke', 'strokeWidth', 'shadow', 'angle']
};

var BaseHandler = function BaseHandler(_ref) {
  var canvas = _ref.canvas,
      handlers = _ref.handlers,
      context = _ref.context,
      config = _ref.config,
      editor = _ref.editor;
  this.canvas = canvas;
  this.handlers = handlers;
  this.context = context;
  this.config = config;
  this.editor = editor;
};

var CanvasHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(CanvasHandler, _BaseHandler);

  function CanvasHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;
    _this.options = {
      width: props.canvas.width,
      height: props.canvas.height
    };
    return _this;
  }

  var _proto = CanvasHandler.prototype;

  _proto.resize = function resize(nextWidth, nextHeight) {
    this.canvas.setWidth(nextWidth).setHeight(nextHeight);
    this.canvas.renderAll();
    var diffWidth = nextWidth / 2 - this.options.width / 2;
    var diffHeight = nextHeight / 2 - this.options.height / 2;
    this.options.width = nextWidth;
    this.options.height = nextHeight;
    var deltaPoint = new fabric.fabric.Point(diffWidth, diffHeight);
    this.canvas.relativePan(deltaPoint);
  };

  return CanvasHandler;
}(BaseHandler);

var ShortcutManager = /*#__PURE__*/function () {
  function ShortcutManager() {}

  var _proto = ShortcutManager.prototype;

  //delete
  _proto.isDelete = function isDelete(event) {
    return event.key === 'Delete';
  } // save or update template
  ;

  _proto.isCtrlS = function isCtrlS(event) {
    return event.ctrlKey && event.code === 'KeyS';
  } // select all
  ;

  _proto.isCtrlA = function isCtrlA(event) {
    return event.ctrlKey && event.code === 'KeyA';
  } // copy
  ;

  _proto.isCtrlC = function isCtrlC(event) {
    return event.ctrlKey && event.code === 'KeyC';
  } // paste
  ;

  _proto.isCtrlV = function isCtrlV(event) {
    return event.ctrlKey && event.code === 'KeyV';
  } // redo
  ;

  _proto.isCtrlY = function isCtrlY(event) {
    return event.ctrlKey && event.code === 'KeyY';
  } // cut
  ;

  _proto.isCtrlX = function isCtrlX(event) {
    return event.ctrlKey && event.code === 'KeyX';
  } // nudge
  ;

  _proto.isArrowUp = function isArrowUp(event) {
    return event.code === 'ArrowUp';
  } // nudge
  ;

  _proto.isArrowDown = function isArrowDown(event) {
    return event.code === 'ArrowDown';
  } // nudge
  ;

  _proto.isArrowLeft = function isArrowLeft(event) {
    return event.code === 'ArrowLeft';
  } // nudge
  ;

  _proto.isArrowRight = function isArrowRight(event) {
    return event.code === 'ArrowRight';
  } // modifier
  ;

  _proto.isShift = function isShift(event) {
    return event.shiftKey;
  } // lineHeight--
  ;

  _proto.isAltDown = function isAltDown(event) {
    return event.altKey && event.code === 'ArrowDown';
  } // lineHeight++
  ;

  _proto.isAltUp = function isAltUp(event) {
    return event.altKey && event.code === 'ArrowUp';
  } // charSpacing++
  ;

  _proto.isAltRight = function isAltRight(event) {
    return event.altKey && event.code === 'ArrowRight';
  } // charSpacing--
  ;

  _proto.isAltLeft = function isAltLeft(event) {
    return event.altKey && event.code === 'ArrowLeft';
  } // redo
  ;

  _proto.isCtrlShiftZ = function isCtrlShiftZ(event) {
    return event.ctrlKey && event.shiftKey && event.code === 'KeyZ';
  } // undo
  ;

  _proto.isCtrlZ = function isCtrlZ(event) {
    return event.ctrlKey && !event.shiftKey && event.code === 'KeyZ';
  } // zoom reset
  ;

  _proto.isCtrlOne = function isCtrlOne(event) {
    return event.ctrlKey && event.key === '1';
  } // zoom in
  ;

  _proto.isCtrlMinus = function isCtrlMinus(event) {
    return event.ctrlKey && event.key === '-';
  } // zoom out
  ;

  _proto.isCtrlEqual = function isCtrlEqual(event) {
    return event.ctrlKey && event.key === '=';
  } // zoom to fit
  ;

  _proto.isCtrlZero = function isCtrlZero(event) {
    return event.ctrlKey && event.key === '0';
  };

  return ShortcutManager;
}();

var shourcutsManager = /*#__PURE__*/new ShortcutManager();

var EventsHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(EventsHandler, _BaseHandler);

  function EventsHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.onMouseDown = function (e) {
      _this.handlers.objectsHandler.pasteStyle(); //@ts-ignore
      // e.e.preventDefault()


      if (e.button === 3) {
        // @ts-ignore
        _this.context.setContextMenuRequest({
          left: e.e.offsetX,
          top: e.e.offsetY,
          target: e.target
        });
      } else {
        _this.context.setContextMenuRequest(null);
      }
    };

    _this.objectModified = function (event) {
      var target = event.target;

      if (target instanceof fabric.fabric.Textbox) {
        _this.scaleTextbox(target);
      }

      _this.handlers.historyHandler.save('object:modified');
    };

    _this.onMouseOut = function () {
      _this.canvas.renderAll();
    };

    _this.onMouseWheel = function (event) {
      var isCtrlKey = event.e.ctrlKey;

      if (isCtrlKey) {
        _this.handleZoom(event);
      }
    };

    _this.handleZoom = function (event) {
      var delta = event.e.deltaY;

      var zoomRatio = _this.canvas.getZoom();

      if (delta > 0) {
        zoomRatio -= 0.02;
      } else {
        zoomRatio += 0.02;
      }

      _this.handlers.zoomHandler.zoomToPoint(new fabric.fabric.Point(_this.canvas.getWidth() / 2, _this.canvas.getHeight() / 2), zoomRatio);

      event.e.preventDefault();
      event.e.stopPropagation();
    };

    _this.handleSelection = function (target) {
      if (target) {
        _this.context.setActiveObject(null);

        var initialSelection = _this.canvas.getActiveObject();

        var isNotMultipleSelection = initialSelection && initialSelection.type === ObjectType.GROUP || initialSelection && initialSelection.type === ObjectType.STATIC_VECTOR;

        if (initialSelection && !isNotMultipleSelection && initialSelection._objects) {
          var filteredObjects = initialSelection._objects.filter(function (object) {
            if (object.type === ObjectType.BACKGROUND) {
              return false;
            }

            return !object.locked;
          });

          _this.canvas.discardActiveObject();

          if (filteredObjects.length > 0) {
            if (filteredObjects.length === 1) {
              _this.canvas.setActiveObject(filteredObjects[0]);

              _this.context.setActiveObject(filteredObjects[0]);
            } else {
              var activeSelection = new fabric.fabric.ActiveSelection(filteredObjects, {
                canvas: _this.canvas
              });

              _this.canvas.setActiveObject(activeSelection);

              _this.context.setActiveObject(activeSelection);
            }
          }
        } else {
          _this.context.setActiveObject(initialSelection);
        }
      } else {
        _this.context.setActiveObject(null);
      }

      _this.canvas.renderAll();
    };

    _this.scaleTextbox = function (target) {
      var fontSize = target.fontSize,
          width = target.width,
          scaleX = target.scaleX;
      target.set({
        fontSize: fontSize * scaleX,
        width: width * scaleX,
        scaleX: 1,
        scaleY: 1
      });
    };

    _this.initialize();

    return _this;
  }

  var _proto = EventsHandler.prototype;

  _proto.initialize = function initialize() {
    this.canvas.wrapperEl.tabIndex = 1;
    this.canvas.wrapperEl.style.outline = 'none'; // @ts-ignore

    this.canvas.on({
      'mouse:down': this.onMouseDown,
      'mouse:up': this.handleSelection,
      'selection:cleared': this.handleSelection,
      'selection:updated': this.handleSelection,
      'mouse:wheel': this.onMouseWheel,
      'mouse:out': this.onMouseOut,
      'object:modified': this.objectModified
    });
    this.canvas.wrapperEl.addEventListener('keydown', this.onKeyDown.bind(this), false);
  };

  _proto.destroy = function destroy() {
    this.canvas.off({
      'mouse:down': this.onMouseDown,
      'mouse:up': this.handleSelection,
      'selection:cleared': this.handleSelection,
      'selection:updated': this.handleSelection,
      'mouse:wheel': this.onMouseWheel,
      'mouse:out': this.onMouseOut,
      'object:modified': this.objectModified
    });
    this.canvas.wrapperEl.removeEventListener('keydown', this.onKeyDown.bind(this));
  };

  _proto.onKeyDown = function onKeyDown(event) {
    if (shourcutsManager.isCtrlZero(event)) {
      event.preventDefault();
      this.handlers.zoomHandler.zoomToFit();
    } else if (shourcutsManager.isCtrlMinus(event)) {
      event.preventDefault();
      this.handlers.zoomHandler.zoomIn();
    } else if (shourcutsManager.isCtrlEqual(event)) {
      event.preventDefault();
      this.handlers.zoomHandler.zoomOut();
    } else if (shourcutsManager.isCtrlOne(event)) {
      event.preventDefault();
      this.handlers.zoomHandler.zoomToOne();
    } else if (shourcutsManager.isCtrlZ(event)) {
      this.handlers.historyHandler.undo();
    } else if (shourcutsManager.isCtrlShiftZ(event)) {
      this.handlers.historyHandler.redo();
    } else if (shourcutsManager.isCtrlY(event)) {
      this.handlers.historyHandler.redo();
    } else if (shourcutsManager.isAltLeft(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.updateCharSpacing(-10);
    } else if (shourcutsManager.isAltRight(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.updateCharSpacing(+10);
    } else if (shourcutsManager.isAltUp(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.updateLineHeight(+0.1);
    } else if (shourcutsManager.isAltDown(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.updateLineHeight(-0.1);
    } else if (shourcutsManager.isCtrlA(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.selectAll();
    } else if (shourcutsManager.isDelete(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.remove();
    } else if (shourcutsManager.isCtrlC(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.copy();
    } else if (shourcutsManager.isCtrlV(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.paste();
    } else if (shourcutsManager.isCtrlX(event)) {
      event.preventDefault();
      this.handlers.objectsHandler.cut();
    } else if (shourcutsManager.isArrowUp(event)) {
      var nudgeValue = -1;

      if (shourcutsManager.isShift(event)) {
        nudgeValue = -10;
      }

      this.handlers.objectsHandler.moveVertical(nudgeValue);
    } else if (shourcutsManager.isArrowDown(event)) {
      var _nudgeValue = 1;

      if (shourcutsManager.isShift(event)) {
        _nudgeValue = 10;
      }

      this.handlers.objectsHandler.moveVertical(_nudgeValue);
    } else if (shourcutsManager.isArrowLeft(event)) {
      var _nudgeValue2 = -1;

      if (shourcutsManager.isShift(event)) {
        _nudgeValue2 = -10;
      }

      this.handlers.objectsHandler.moveHorizontal(_nudgeValue2);
    } else if (shourcutsManager.isArrowRight(event)) {
      var _nudgeValue3 = 1;

      if (shourcutsManager.isShift(event)) {
        _nudgeValue3 = 10;
      }

      this.handlers.objectsHandler.moveHorizontal(_nudgeValue3);
    }
  };

  return EventsHandler;
}(BaseHandler);

var FrameHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(FrameHandler, _BaseHandler);

  function FrameHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.getFrame = function () {
      return _this.canvas.getObjects().find(function (object) {
        return object.type === ObjectType.FRAME;
      });
    };

    _this.setSize = function (options) {
      var frame = _this.getFrame();

      if (frame) {
        var width = options.width,
            height = options.height;
        frame.set('width', width);
        frame.set('height', height);
        frame.center();

        _this.handlers.backgroundHandler.setSize(options);
      }

      _this.handlers.zoomHandler.zoomToFit();
    };

    _this.update = function (options) {
      var frame = _this.getFrame();

      var width = options.width,
          height = options.height;
      frame.set('width', width);
      frame.set('height', height);
      frame.center();

      _this.handlers.zoomHandler.zoomToFit();
    };

    _this.setBackgroundColor = function (color) {
      var frame = _this.getFrame();

      frame.set('fill', color);

      _this.canvas.renderAll();
    };

    _this.getOptions = function () {
      var frame = _this.getFrame();

      return frame.toJSON(_this.handlers.propertiesToInclude);
    };

    _this.getFitRatio = function () {
      var canvasWidth = _this.canvas.getWidth() - 120;
      var canvasHeight = _this.canvas.getHeight() - 120;

      var options = _this.getOptions();

      var scaleX = canvasWidth / options.width;
      var scaleY = canvasHeight / options.height;

      if (options.height >= options.width) {
        scaleX = scaleY;

        if (canvasWidth < options.width * scaleX) {
          scaleX = scaleX * (canvasWidth / (options.width * scaleX));
        }
      } else {
        if (canvasHeight < options.height * scaleX) {
          scaleX = scaleX * (canvasHeight / (options.height * scaleX));
        }
      }

      return scaleX;
    };

    _this.initialize();

    return _this;
  }

  var _proto = FrameHandler.prototype;

  _proto.initialize = function initialize() {
    var _this2 = this;

    var frame = new fabric.fabric.Frame({
      width: 1280,
      height: 720,
      id: 'frame',
      name: 'Initial Frame',
      fill: '#ffffff',
      hoverCursor: 'default',
      absolutePositioned: this.config.clipToFrame
    });
    var background = new fabric.fabric.Background({
      width: 1280,
      height: 720,
      fill: '#ffffff',
      id: 'background',
      name: 'Initial Frame'
    });
    this.canvas.add(frame);
    this.canvas.add(background);
    frame.center();
    background.center();
    var watchZoom = setInterval(function () {
      if (_this2.handlers.zoomHandler.zoomToFit && _this2.handlers.scrollbarHandler.updateScrollPosition) {
        _this2.handlers.zoomHandler.zoomToFit();

        _this2.handlers.scrollbarHandler.updateScrollPosition();

        _this2.handlers.historyHandler.save('init');

        clearInterval(watchZoom);
      }
    }, 50);
  };

  return FrameHandler;
}(BaseHandler);

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  define(IteratorPrototype, iteratorSymbol, function () {
    return this;
  });

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = GeneratorFunctionPrototype;
  define(Gp, "constructor", GeneratorFunctionPrototype);
  define(GeneratorFunctionPrototype, "constructor", GeneratorFunction);
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
    return this;
  });
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  define(Gp, iteratorSymbol, function() {
    return this;
  });

  define(Gp, "toString", function() {
    return "[object Generator]";
  });

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, in modern engines
  // we can explicitly access globalThis. In older engines we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  if (typeof globalThis === "object") {
    globalThis.regeneratorRuntime = runtime;
  } else {
    Function("r", "regeneratorRuntime = r")(runtime);
  }
}
});

//@ts-nocheck
function loadImageFromURL(src) {
  return new Promise(function (resolve) {
    var image = new Image();
    image.src = src;
    image.crossOrigin = 'Anonymous';

    image.onload = function () {
      resolve(image);
    };
  });
}

var ObjectToFabric = /*#__PURE__*/function (_ObjectType$STATIC_TE, _ObjectType$DYNAMIC_T, _ObjectType$DYNAMIC_I, _ObjectType$STATIC_IM, _ObjectType$STATIC_PA, _ObjectType$GROUP, _ObjectType$BACKGROUN, _ObjectType$STATIC_VE) {
  function ObjectToFabric() {}

  var _proto = ObjectToFabric.prototype;

  _proto.run = /*#__PURE__*/function () {
    var _run = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(item, options, inGroup) {
      var object;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (inGroup === void 0) {
                inGroup = false;
              }

              _context.t0 = item.type;
              _context.next = _context.t0 === ObjectType.STATIC_TEXT ? 4 : _context.t0 === ObjectType.STATIC_IMAGE ? 8 : _context.t0 === ObjectType.STATIC_VECTOR ? 12 : _context.t0 === ObjectType.STATIC_PATH ? 16 : _context.t0 === ObjectType.DYNAMIC_TEXT ? 20 : _context.t0 === ObjectType.DYNAMIC_IMAGE ? 24 : _context.t0 === ObjectType.BACKGROUND ? 28 : _context.t0 === ObjectType.GROUP ? 32 : 36;
              break;

            case 4:
              _context.next = 6;
              return this[ObjectType.STATIC_TEXT](item, options, inGroup);

            case 6:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 8:
              _context.next = 10;
              return this[ObjectType.STATIC_IMAGE](item, options, inGroup);

            case 10:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 12:
              _context.next = 14;
              return this[ObjectType.STATIC_VECTOR](item, options, inGroup);

            case 14:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 16:
              _context.next = 18;
              return this[ObjectType.STATIC_PATH](item, options, inGroup);

            case 18:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 20:
              _context.next = 22;
              return this[ObjectType.DYNAMIC_TEXT](item, options, inGroup);

            case 22:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 24:
              _context.next = 26;
              return this[ObjectType.DYNAMIC_IMAGE](item, options, inGroup);

            case 26:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 28:
              _context.next = 30;
              return this[ObjectType.BACKGROUND](item, options, inGroup);

            case 30:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 32:
              _context.next = 34;
              return this[ObjectType.GROUP](item, options, inGroup);

            case 34:
              object = _context.sent;
              return _context.abrupt("break", 36);

            case 36:
              return _context.abrupt("return", object);

            case 37:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function run(_x, _x2, _x3) {
      return _run.apply(this, arguments);
    }

    return run;
  }();

  _proto[_ObjectType$STATIC_TE] = function (item, options, inGroup) {
    var _this = this;

    return new Promise(function (resolve, reject) {
      try {
        var baseOptions = _this.getBaseOptions(item, options, inGroup);

        var metadata = item.metadata;
        var textAlign = metadata.textAlign,
            fontFamily = metadata.fontFamily,
            fontSize = metadata.fontSize,
            fontWeight = metadata.fontWeight,
            charSpacing = metadata.charSpacing,
            lineheight = metadata.lineheight,
            text = metadata.text;

        var textOptions = _extends({}, baseOptions, {
          text: text ? text : 'Default Text'
        }, textAlign && {
          textAlign: textAlign
        }, fontFamily && {
          fontFamily: fontFamily
        }, fontSize && {
          fontSize: fontSize
        }, fontWeight && {
          fontWeight: fontWeight
        }, charSpacing && {
          charSpacing: charSpacing
        }, lineheight && {
          lineheight: lineheight
        });

        var element = new fabric.fabric.StaticText(textOptions);
        var top = element.top,
            left = element.left,
            width = element.width,
            height = element.height;

        if (isNaN$1(top) || isNaN$1(left)) {
          element.set({
            top: options.top + options.height / 2 - height / 2,
            left: options.left + options.width / 2 - width / 2
          });
        }

        resolve(element);
      } catch (err) {
        reject(err);
      }
    });
  };

  _proto[_ObjectType$DYNAMIC_T] = function (item, options, inGroup) {
    var _this2 = this;

    return new Promise(function (resolve, reject) {
      try {
        var baseOptions = _this2.getBaseOptions(item, options, inGroup);

        var metadata = item.metadata;
        var textAlign = metadata.textAlign,
            fontFamily = metadata.fontFamily,
            fontSize = metadata.fontSize,
            fontWeight = metadata.fontWeight,
            charSpacing = metadata.charSpacing,
            lineheight = metadata.lineheight,
            keyValues = metadata.keyValues,
            text = metadata.text,
            keys = metadata.keys;

        var textOptions = _extends({}, baseOptions, {
          keyValues: keyValues ? keyValues : [],
          text: text ? text : 'Default Text',
          keys: keys ? keys : []
        }, textAlign && {
          textAlign: textAlign
        }, fontFamily && {
          fontFamily: fontFamily
        }, fontSize && {
          fontSize: fontSize
        }, fontWeight && {
          fontWeight: fontWeight
        }, charSpacing && {
          charSpacing: charSpacing
        }, lineheight && {
          lineheight: lineheight
        });

        var element = new fabric.fabric.DynamicText(textOptions);
        var top = element.top,
            left = element.left,
            width = element.width,
            height = element.height;

        if (isNaN$1(top) || isNaN$1(left)) {
          element.set({
            top: options.top + options.height / 2 - height / 2,
            left: options.left + options.width / 2 - width / 2
          });
        }

        resolve(element);
      } catch (err) {
        reject(err);
      }
    });
  };

  _proto[_ObjectType$DYNAMIC_I] = function (item, options, inGroup) {
    var _this3 = this;

    return new Promise(function (resolve, reject) {
      try {
        var metadata = item.metadata;

        var baseOptions = _this3.getBaseOptions(item, options, inGroup);

        var keyValues = metadata.keyValues; // @ts-ignore

        var element = new fabric.fabric.DynamicImage(_extends({}, baseOptions, {
          keys: item.keys,
          keyValues: keyValues ? keyValues : []
        }));
        resolve(element);
      } catch (err) {
        reject(err);
      }
    });
  };

  _proto[_ObjectType$STATIC_IM] = function (item, options, inGroup) {
    var _this4 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(resolve, reject) {
        var baseOptions, src, image, width, height, element, top, left;
        return runtime_1.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.prev = 0;
                baseOptions = _this4.getBaseOptions(item, options, inGroup);
                src = item.metadata.src;
                _context2.next = 5;
                return loadImageFromURL(src);

              case 5:
                image = _context2.sent;
                width = baseOptions.width, height = baseOptions.height;

                if (!width || !height) {
                  baseOptions.width = image.width;
                  baseOptions.height = image.height;
                }

                element = new fabric.fabric.StaticImage(image, _extends({}, baseOptions, {
                  cropX: item.metadata.cropX || 0,
                  cropY: item.metadata.cropY || 0
                }));
                top = element.top, left = element.left;

                if (isNaN$1(top) || isNaN$1(left)) {
                  element.set({
                    top: options.top,
                    left: options.left
                  });
                  element.scaleToWidth(480);
                }

                resolve(element);
                _context2.next = 17;
                break;

              case 14:
                _context2.prev = 14;
                _context2.t0 = _context2["catch"](0);
                reject(_context2.t0);

              case 17:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, null, [[0, 14]]);
      }));

      return function (_x4, _x5) {
        return _ref.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$STATIC_PA] = function (item, options, inGroup) {
    var _this5 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(resolve, reject) {
        var baseOptions, path, fill, element, top, left;
        return runtime_1.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                try {
                  baseOptions = _this5.getBaseOptions(item, options, inGroup);
                  path = item.metadata.value;
                  fill = item.metadata.fill;
                  element = new fabric.fabric.StaticPath(_extends({}, baseOptions, {
                    path: path,
                    fill: fill ? fill : '#000000'
                  }));
                  top = element.top, left = element.left;

                  if (isNaN$1(top) || isNaN$1(left)) {
                    element.set({
                      top: options.top,
                      left: options.left
                    });
                    element.scaleToWidth(320);
                  }

                  resolve(element);
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3);
      }));

      return function (_x6, _x7) {
        return _ref2.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$GROUP] = function (item, options, inGroup) {
    var _this6 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref3 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee4(resolve, reject) {
        var baseOptions, objects, _iterator, _step, object, element;

        return runtime_1.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                _context4.prev = 0;
                baseOptions = _this6.getBaseOptions(item, options, inGroup);
                objects = [];
                _iterator = _createForOfIteratorHelperLoose(item.objects);

              case 4:
                if ((_step = _iterator()).done) {
                  _context4.next = 13;
                  break;
                }

                object = _step.value;
                _context4.t0 = objects;
                _context4.next = 9;
                return _this6.run(object, options, true);

              case 9:
                _context4.t1 = _context4.sent;
                objects = _context4.t0.concat.call(_context4.t0, _context4.t1);

              case 11:
                _context4.next = 4;
                break;

              case 13:
                element = new fabric.fabric.Group(objects, baseOptions);
                resolve(element);
                _context4.next = 20;
                break;

              case 17:
                _context4.prev = 17;
                _context4.t2 = _context4["catch"](0);
                reject(_context4.t2);

              case 20:
              case "end":
                return _context4.stop();
            }
          }
        }, _callee4, null, [[0, 17]]);
      }));

      return function (_x8, _x9) {
        return _ref3.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$BACKGROUN] = function (item, options, inGroup) {
    var _this7 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref4 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee5(resolve, reject) {
        var baseOptions, fill, element, top, left;
        return runtime_1.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                try {
                  baseOptions = _this7.getBaseOptions(item, options, inGroup);
                  fill = item.metadata.fill;
                  element = new fabric.fabric.Background(_extends({}, baseOptions, {
                    fill: fill ? fill : '#000000',
                    id: 'background',
                    name: ''
                  }));
                  top = element.top, left = element.left;

                  if (isNaN$1(top) || isNaN$1(left)) {
                    element.set({
                      top: options.top,
                      left: options.left
                    });
                    element.scaleToWidth(320);
                  }

                  resolve(element);
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context5.stop();
            }
          }
        }, _callee5);
      }));

      return function (_x10, _x11) {
        return _ref4.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$STATIC_VE] = function (item, options, inGroup) {
    var _this8 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref5 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee6(resolve, reject) {
        var baseOptions, src;
        return runtime_1.wrap(function _callee6$(_context6) {
          while (1) {
            switch (_context6.prev = _context6.next) {
              case 0:
                try {
                  baseOptions = _this8.getBaseOptions(item, options, inGroup);
                  src = item.metadata.src;
                  fabric.fabric.loadSVGFromURL(src, function (objects, opts) {
                    var width = baseOptions.width,
                        height = baseOptions.height,
                        top = baseOptions.top,
                        left = baseOptions.left;

                    if (!width || !height) {
                      baseOptions.width = opts.width;
                      baseOptions.height = opts.height;
                      baseOptions.top = options.top;
                      baseOptions.left = options.left;
                    }

                    var object = new fabric.fabric.StaticVector(objects, opts, _extends({}, baseOptions, {
                      src: src
                    }));

                    if (isNaN$1(top) || isNaN$1(left)) {
                      object.set({
                        top: options.top,
                        left: options.left
                      });
                      object.scaleToWidth(320);
                    }

                    resolve(object);
                  });
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context6.stop();
            }
          }
        }, _callee6);
      }));

      return function (_x12, _x13) {
        return _ref5.apply(this, arguments);
      };
    }());
  };

  _proto.getBaseOptions = function getBaseOptions(item, options, inGroup) {
    var id = item.id,
        name = item.name,
        left = item.left,
        top = item.top,
        width = item.width,
        height = item.height,
        scaleX = item.scaleX,
        scaleY = item.scaleY,
        stroke = item.stroke,
        strokeWidth = item.strokeWidth,
        angle = item.angle,
        opacity = item.opacity,
        flipX = item.flipX,
        flipY = item.flipY,
        skewX = item.skewX,
        skewY = item.skewY,
        originX = item.originX,
        originY = item.originY,
        animation = item.animation;
    var metadata = item.metadata ? item.metadata : {};
    var fill = metadata.fill;
    var baseOptions = {
      id: id,
      name: name,
      angle: angle ? angle : 0,
      top: inGroup ? top : options.top + top,
      left: inGroup ? left : options.left + left,
      width: width,
      height: height,
      originX: originX || 'left',
      originY: originY || 'top',
      scaleX: scaleX || 1,
      scaleY: scaleY || 1,
      fill: fill || '#000000',
      stroke: stroke ? stroke : '#ffffff',
      strokeWidth: strokeWidth ? strokeWidth : 0,
      opacity: opacity ? opacity : 1,
      flipX: flipX ? flipX : false,
      flipY: flipY ? flipY : false,
      skewX: skewX ? skewX : 0,
      skewY: skewY ? skewY : 0,
      metadata: metadata,
      animation: animation
    };
    return baseOptions;
  };

  return ObjectToFabric;
}(ObjectType.STATIC_TEXT, ObjectType.DYNAMIC_TEXT, ObjectType.DYNAMIC_IMAGE, ObjectType.STATIC_IMAGE, ObjectType.STATIC_PATH, ObjectType.GROUP, ObjectType.BACKGROUND, ObjectType.STATIC_VECTOR);

var objectToFabric = /*#__PURE__*/new ObjectToFabric();

function angleToPoint(angle, sx, sy) {
  while (angle < 0) {
    angle += 360;
  }

  angle %= 360;
  var a = sy,
      b = a + sx,
      c = b + sy,
      // 3 first corners
  p = (sx + sy) * 2,
      // perimeter
  rp = p * 0.00277,
      // ratio between perimeter & 360
  pp = Math.round((angle * rp + (sy >> 1)) % p); // angle position on perimeter

  if (pp <= a) return {
    x: 0,
    y: sy - pp
  };
  if (pp <= b) return {
    y: 0,
    x: pp - a
  };
  if (pp <= c) return {
    x: sx,
    y: pp - b
  };
  return {
    y: sy,
    x: sx - (pp - c)
  };
}

var _excluded = ["fill"];

var ObjectHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(ObjectHandler, _BaseHandler);

  function ObjectHandler() {
    var _this;

    _this = _BaseHandler.apply(this, arguments) || this;

    _this.add = /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(item) {
        var _assertThisInitialize, canvas, options, object, frame;

        return runtime_1.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _assertThisInitialize = _assertThisInitialized(_this), canvas = _assertThisInitialize.canvas;
                options = _this.handlers.frameHandler.getOptions();
                _context.next = 4;
                return objectToFabric.run(item, options);

              case 4:
                object = _context.sent;

                if (_this.config.clipToFrame) {
                  frame = _this.handlers.frameHandler.getFrame();
                  object.clipPath = frame;
                }

                canvas.add(object);
                object.center();
                canvas.setActiveObject(object);

                _this.context.setActiveObject(object);

                _this.handlers.historyHandler.save('object:created');

              case 11:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function (_x) {
        return _ref.apply(this, arguments);
      };
    }();

    _this.update = function (options) {
      var activeObject = _this.canvas.getActiveObject();

      var canvas = _this.canvas;

      if (activeObject) {
        var _loop = function _loop(property) {
          if (property === 'angle' || property === 'top' || property === 'left') {
            if (property === 'angle') {
              activeObject.rotate(options['angle']);
              canvas.requestRenderAll();
            } else {
              activeObject.set(property, options[property]);
              canvas.requestRenderAll();
            }
          } else {
            // @ts-ignore
            if (activeObject._objects) {
              // @ts-ignore
              activeObject._objects.forEach(function (object) {
                if (property === 'metadata') {
                  object.set('metadata', _extends({}, object.metadata, options['metadata']));
                } else {
                  object.set(property, options[property]);
                }

                object.setCoords();
              });
            } else {
              if (property === 'metadata') {
                // @ts-ignore
                activeObject.set('metadata', _extends({}, activeObject.metadata, options[property]));
              } else {
                // @ts-ignore
                activeObject.set(property, options[property]);
              }

              activeObject.setCoords();
            }
          }

          activeObject.set(property, options[property]);
          canvas.requestRenderAll();
        };

        for (var property in options) {
          _loop(property);
        }

        _this.handlers.historyHandler.save('object:updated');
      }
    };

    _this.clear = function () {
      var frame = _this.handlers.frameHandler.getFrame();

      _this.canvas.getObjects().forEach(function (object) {
        if (object.type !== 'Frame') {
          _this.canvas.remove(object);
        }
      });

      frame.set('fill', '#ffffff');

      _this.canvas.renderAll();
    };

    _this.deselect = function () {
      _this.canvas.discardActiveObject();

      _this.canvas.requestRenderAll();
    };

    _this.moveVertical = function (value) {
      var activeObject = _this.canvas.getActiveObject();

      var top = activeObject.top + value;

      _this.update({
        top: top
      });
    };

    _this.moveHorizontal = function (value) {
      var activeObject = _this.canvas.getActiveObject();

      var left = activeObject.left + value;

      _this.update({
        left: left
      });
    };

    _this.updateLineHeight = function (value) {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject.type === 'DynamicText') {
        var lineHeight = activeObject.lineHeight + value;

        _this.update({
          lineHeight: lineHeight
        });
      }
    };

    _this.updateCharSpacing = function (value) {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject.type === 'DynamicText') {
        var charSpacing = activeObject.charSpacing + value;

        _this.update({
          charSpacing: charSpacing
        });
      }
    };

    _this.cut = function () {
      _this.copy();

      _this.isCut = true;

      _this.remove();
    };

    _this.copy = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject) {
        _this.clipboard = activeObject;
      }
    };

    _this.clone = function () {
      if (_this.canvas) {
        var activeObject = _this.canvas.getActiveObject();

        var frame = _this.handlers.frameHandler.getFrame();

        _this.canvas.discardActiveObject();

        _this.duplicate(activeObject, frame, function (duplicates) {
          var selection = new fabric.fabric.ActiveSelection(duplicates, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);

          _this.canvas.requestRenderAll();
        });
      }
    };

    _this.paste = function () {
      var object = _this.clipboard;

      if (object) {
        var frame = _this.handlers.frameHandler.getFrame();

        _this.canvas.discardActiveObject();

        _this.duplicate(object, frame, function (duplicates) {
          var selection = new fabric.fabric.ActiveSelection(duplicates, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);

          _this.canvas.requestRenderAll();
        });
      }
    };
    /**
     * Remove active object
     */


    _this.remove = function () {
      _this.canvas.getActiveObjects().forEach(function (obj) {
        _this.canvas.remove(obj);
      });

      _this.canvas.discardActiveObject().renderAll();

      _this.handlers.historyHandler.save('object:removed');
    };

    _this.selectAll = function () {
      _this.canvas.discardActiveObject();

      var filteredObjects = _this.canvas.getObjects().filter(function (object) {
        if (object.type === 'Frame') {
          return false;
        } else if (!object.evented) {
          return false; //@ts-ignore
        } else if (object.locked) {
          return false;
        }

        return true;
      });

      if (!filteredObjects.length) {
        return;
      }

      if (filteredObjects.length === 1) {
        _this.canvas.setActiveObject(filteredObjects[0]);

        _this.canvas.renderAll();

        _this.context.setActiveObject(filteredObjects[0]);

        return;
      }

      var activeSelection = new fabric.fabric.ActiveSelection(filteredObjects, {
        canvas: _this.canvas
      });

      _this.canvas.setActiveObject(activeSelection);

      _this.canvas.renderAll();

      _this.context.setActiveObject(activeSelection);
    };

    _this.copyStyle = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject) {
        var clonableProps = copyStyleProps[activeObject.type];
        var clonedProps = pick(activeObject.toJSON(), clonableProps);
        _this.copyStyleClipboard = {
          objectType: activeObject.type,
          props: clonedProps
        };

        _this.handlers.backgroundHandler.setHoverCursor(getCopyStyleCursor());

        _this.canvas.hoverCursor = getCopyStyleCursor();
        _this.canvas.defaultCursor = getCopyStyleCursor();
      }
    };

    _this.pasteStyle = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject && _this.copyStyleClipboard) {
        if (activeObject.type === _this.copyStyleClipboard.objectType) {
          var _this$copyStyleClipbo = _this.copyStyleClipboard.props,
              fill = _this$copyStyleClipbo.fill,
              basicProps = _objectWithoutPropertiesLoose(_this$copyStyleClipbo, _excluded);

          activeObject.set(basicProps);

          if (fill) {
            if (fill.type) {
              activeObject.set({
                fill: new fabric.fabric.Gradient(fill)
              });
            } else {
              activeObject.set({
                fill: fill
              });
            }
          }
        }
      }

      _this.copyStyleClipboard = null;

      _this.handlers.backgroundHandler.setHoverCursor('default');

      _this.canvas.hoverCursor = 'move';
      _this.canvas.defaultCursor = 'default';
    };
    /**
     * OBJECT POSITION
     */

    /**
     * Moves an object or a selection up in stack of drawn objects.
     */


    _this.bringForward = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject) {
        _this.canvas.bringForward(activeObject);
      }
    };
    /**
     * Moves an object or the objects of a multiple selection to the top of the stack of drawn objects
     */


    _this.bringToFront = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject) {
        _this.canvas.bringToFront(activeObject);
      }
    };
    /**
     * Moves an object or a selection down in stack of drawn objects.
     */


    _this.sendBackwards = function () {
      var objects = _this.canvas.getObjects();

      var activeObject = _this.canvas.getActiveObject();

      var index = objects.findIndex(function (o) {
        return o === activeObject;
      });

      if (activeObject && index > 1) {
        _this.canvas.sendBackwards(activeObject);
      }
    };
    /**
     * Moves an object to specified level in stack of drawn objects.
     */


    _this.sendToBack = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject) {
        activeObject.moveTo(1);
      }
    };
    /**
     * ALIGNMENT TO FRAME OR GROUP
     */

    /**
     * Moves an object to the top of the frame. If multiple objects are selected, will move all objects to the top of the selection.
     */


    _this.alignTop = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refTop = activeObject.top;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            currentObject.set('top', refTop);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          currentObject.set('top', frame.top);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * Moves an object to the middle of the frame. If multiple objects are selected, will move all objects to the middle of the selection.
     */


    _this.alignMiddle = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refTop = activeObject.top;
          var refHeight = activeObject.height;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            var currentObjectHeight = currentObject.getScaledHeight();
            currentObject.set('top', refTop + refHeight / 2 - currentObjectHeight / 2);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          var currentObjectHeight = currentObject.getScaledHeight();
          currentObject.set('top', frame.top + frame.height / 2 - currentObjectHeight / 2);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * Moves an object to the bottom of the frame. If multiple objects are selected, will move all objects to the bottom of the selection.
     */


    _this.alignBottom = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refTop = activeObject.top;
          var refHeight = activeObject.height;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            var currentObjectHeight = currentObject.getScaledHeight();
            currentObject.set('top', refTop + refHeight - currentObjectHeight);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          var currentObjectHeight = currentObject.getScaledHeight();
          currentObject.set('top', frame.top + frame.height - currentObjectHeight);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * Moves an object to the left of the frame. If multiple objects are selected, will move all objects to the left of the selection.
     */


    _this.alignLeft = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refLeft = activeObject.left;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            currentObject.set('left', refLeft);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          currentObject.set('left', frame.left);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * Moves an object to the center of the frame. If multiple objects are selected, will move all objects to the center of the selection.
     */


    _this.alignCenter = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refLeft = activeObject.left;
          var refWidth = activeObject.width;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            var currentObjectWidth = currentObject.getScaledWidth();
            currentObject.set('left', refLeft + refWidth / 2 - currentObjectWidth / 2);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          var currentObjectWidth = currentObject.getScaledWidth();
          currentObject.set('left', frame.left + frame.width / 2 - currentObjectWidth / 2);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * Moves an object to the right of the frame. If multiple objects are selected, will move all objects to the right of the selection.
     */


    _this.alignRight = function () {
      var activeObject = _this.canvas.getActiveObject();

      var frame = _this.handlers.frameHandler.getFrame();

      if (activeObject) {
        if (activeObject instanceof fabric.fabric.Group) {
          var selectedObjects = activeObject._objects;
          var refLeft = activeObject.left;
          var refWidth = activeObject.width;

          _this.canvas.discardActiveObject();

          selectedObjects.forEach(function (object) {
            var currentObject = object;
            var currentObjectWidth = currentObject.getScaledWidth();
            currentObject.set('left', refLeft + refWidth - currentObjectWidth);
          });
          var selection = new fabric.fabric.ActiveSelection(selectedObjects, {
            canvas: _this.canvas
          });

          _this.canvas.setActiveObject(selection);
        } else {
          var currentObject = activeObject;
          var currentObjectWidth = currentObject.getScaledWidth();
          currentObject.set('left', frame.left + frame.width - currentObjectWidth);
        }

        _this.canvas.requestRenderAll();
      }
    };
    /**
     * SHADOW
     */


    _this.setShadow = function (options) {
      var activeObject = _this.canvas.getActiveObject();

      if (activeObject instanceof fabric.fabric.Group) {
        activeObject._objects.forEach(function (object) {
          _this.setObjectShadow(object, options);
        });
      } else {
        _this.setObjectShadow(activeObject, options);
      }

      _this.canvas.requestRenderAll();

      _this.handlers.historyHandler.save('object:updated');
    };

    _this.setObjectShadow = function (object, options) {
      if (options.enabled) {
        object.set('shadow', new fabric.fabric.Shadow(options));
      } else {
        object.set('shadow', null);
      }
    };
    /**
     * GRADIENT
     */


    _this.setGradient = function (_ref2) {
      var angle = _ref2.angle,
          colors = _ref2.colors;

      var activeObject = _this.canvas.getActiveObject();

      if (activeObject instanceof fabric.fabric.Group) {
        activeObject._objects.forEach(function (object) {
          _this.setObjectGradient(object, angle, colors);
        });
      } else {
        _this.setObjectGradient(activeObject, angle, colors);
      }

      _this.canvas.requestRenderAll();

      _this.handlers.historyHandler.save('object:updated');
    };

    _this.setObjectGradient = function (object, angle, colors) {
      var odx = object.width >> 1;
      var ody = object.height >> 1;
      var startPoint = angleToPoint(angle, object.width, object.height);
      var endPoint = {
        x: object.width - startPoint.x,
        y: object.height - startPoint.y
      };
      object.set('fill', new fabric.fabric.Gradient({
        type: 'linear',
        coords: {
          x1: startPoint.x - odx,
          y1: startPoint.y - ody,
          x2: endPoint.x - odx,
          y2: endPoint.y - ody
        },
        colorStops: [{
          offset: 0,
          color: colors[0]
        }, {
          offset: 1,
          color: colors[1]
        }]
      }));
    };

    _this.group = function () {
      var frame = _this.handlers.frameHandler.getFrame();

      var activeObject = _this.canvas.getActiveObject();

      if (!activeObject) {
        return;
      }

      if (activeObject.type !== ObjectType.ACTIVE_SELECTION) {
        return;
      }

      if (activeObject instanceof fabric.fabric.Group) {
        activeObject._objects.forEach(function (object) {
          object.clipPath = null;
        });
      }

      var group = activeObject.toGroup();
      group.clipPath = frame;

      _this.canvas.renderAll();

      _this.handlers.historyHandler.save('group');
    };

    _this.ungroup = function () {
      var frame = _this.handlers.frameHandler.getFrame();

      var activeObject = _this.canvas.getActiveObject();

      if (!activeObject) {
        return;
      }

      if (activeObject.type !== ObjectType.GROUP) {
        return;
      }

      var activeSelection = activeObject.toActiveSelection();

      activeSelection._objects.forEach(function (object) {
        object.clipPath = frame;
      });

      _this.canvas.renderAll();

      _this.context.setActiveObject(activeSelection);

      _this.handlers.historyHandler.save('ungroup');
    };

    _this.lock = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (!activeObject) {
        return;
      } // @ts-ignore


      if (activeObject._objects) {
        // @ts-ignore
        activeObject._objects.forEach(function (object) {
          object.set({
            hasControls: false,
            lockMovementY: true,
            lockMovementX: true,
            locked: true
          });
        });

        activeObject.set({
          hasControls: false,
          lockMovementY: true,
          lockMovementX: true,
          locked: true
        });
      } else {
        activeObject.set({
          hasControls: false,
          lockMovementY: true,
          lockMovementX: true,
          locked: true
        });
      }

      _this.canvas.renderAll();

      _this.handlers.historyHandler.save('object:updated');
    };

    _this.unlock = function () {
      var activeObject = _this.canvas.getActiveObject();

      if (!activeObject) {
        return;
      } // @ts-ignore


      if (activeObject._objects) {
        // @ts-ignore
        activeObject._objects.forEach(function (object) {
          object.set({
            hasControls: true,
            lockMovementY: false,
            lockMovementX: false,
            locked: false
          });
        }); // @ts-ignore


        activeObject.set({
          hasControls: true,
          lockMovementY: false,
          lockMovementX: false,
          locked: false
        });
      } else {
        // @ts-ignore
        activeObject.set({
          hasControls: true,
          lockMovementY: false,
          lockMovementX: false,
          locked: false
        });
      }

      _this.canvas.renderAll();

      _this.handlers.historyHandler.save('object:updated');
    };

    _this.findByName = function (name) {
      return _this.canvas.getObjects().filter(function (o) {
        return o.name === name;
      });
    };

    _this.removeByName = function (name) {
      _this.canvas.getObjects().forEach(function (o) {
        if (o.name === name) {
          _this.canvas.remove(o);

          _this.handlers.historyHandler.save('object:removed');
        }
      });

      _this.canvas.requestRenderAll();
    };

    _this.findById = function (id) {
      return _this.canvas.getObjects().filter(function (o) {
        return o.id === id;
      });
    };

    _this.removeById = function (id) {
      _this.canvas.getObjects().forEach(function (o) {
        if (o.id === id) {
          _this.canvas.remove(o);

          _this.handlers.historyHandler.save('object:removed');
        }
      });

      _this.canvas.requestRenderAll();
    };

    return _this;
  }

  var _proto = ObjectHandler.prototype;

  _proto.duplicate = function duplicate(object, frame, callback) {
    var _this2 = this;

    if (object instanceof fabric.fabric.Group) {
      (function () {
        var objects = object.getObjects();
        var duplicates = [];

        var _loop2 = function _loop2(i) {
          _this2.duplicate(objects[i], frame, function (clones) {
            duplicates.push.apply(duplicates, clones);

            if (i == objects.length - 1) {
              callback(duplicates);
            }
          });
        };

        for (var i = 0; i < objects.length; i++) {
          _loop2(i);
        }
      })();
    } else {
      object.clone(function (clone) {
        clone.clipPath = null;
        clone.set({
          left: object.left + 10,
          top: object.top + 10
        });

        if (_this2.config.clipToFrame) {
          var _frame = _this2.handlers.frameHandler.getFrame();

          clone.clipPath = _frame;
        }

        _this2.canvas.add(clone);

        callback([clone]);
      }, ['keyValues', 'src']);
    }
  };

  return ObjectHandler;
}(BaseHandler);

var HistoryHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(HistoryHandler, _BaseHandler);

  function HistoryHandler() {
    var _this;

    _this = _BaseHandler.apply(this, arguments) || this;
    _this.redos = [];
    _this.undos = [];
    _this.state = [];
    _this.active = false;

    _this.getStatus = function () {
      return {
        hasUndo: _this.undos.length > 1,
        hasRedo: _this.undos.length > 0,
        undos: _this.undos,
        redos: _this.redos,
        state: _this.state
      };
    };

    _this.save = function (type) {
      try {
        if (_this.state) {
          var json = _this.state;

          _this.undos.push({
            type: type,
            json: json
          });

          var canvasJSON = _this.canvas.toJSON(_this.handlers.propertiesToInclude); // @ts-ignore


          canvasJSON.objects.forEach(function (object) {
            if (object.clipPath) {
              // @ts-ignore
              fabric.fabric.util.enlivenObjects([object.clipPath], function (arg1) {
                object.clipPath = arg1[0];
              });
            }
          }); // @ts-ignore

          _this.state = canvasJSON.objects;
        }
      } catch (err) {
        console.log(err);
      }

      _this.editor.emit('history:changed', {
        hasUndo: _this.undos.length > 1,
        hasRedo: _this.redos.length > 0
      });
    };

    _this.clear = function () {
      _this.redos = [];
      _this.undos = [];
    };

    _this.undo = throttle(function () {
      if (_this.undos.length > 1) {
        var undo = _this.undos.pop();

        if (!undo) {
          return;
        }

        _this.redos.push({
          type: 'redo',
          json: _this.state
        });

        _this.replay(undo);
      }
    }, 100);
    _this.redo = throttle(function () {
      var redo = _this.redos.pop();

      if (!redo) {
        return;
      }

      _this.undos.push({
        type: 'undo',
        json: _this.state
      });

      _this.replay(redo);
    }, 100);

    _this.replay = /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(transaction) {
        var objects;
        return runtime_1.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.handlers.objectsHandler.clear();

                objects = transaction.json;
                _this.state = objects;
                _this.active = true;
                fabric.fabric.util.enlivenObjects(objects, function (enlivenObjects) {
                  enlivenObjects.forEach(function (enlivenObject) {
                    if (enlivenObject.type !== 'Frame') {
                      _this.canvas.add(enlivenObject);
                    }
                  });

                  _this.editor.emit('history:changed', {
                    hasUndo: _this.undos.length > 1,
                    hasRedo: _this.redos.length > 0
                  });
                }, null);
                _this.active = false;

              case 6:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function (_x) {
        return _ref.apply(this, arguments);
      };
    }();

    _this.getAll = function () {
      return {
        undos: _this.undos,
        redos: _this.redos,
        state: _this.state
      };
    };

    return _this;
  }

  return HistoryHandler;
}(BaseHandler);

var ZoomHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(ZoomHandler, _BaseHandler);

  function ZoomHandler() {
    return _BaseHandler.apply(this, arguments) || this;
  }

  var _proto = ZoomHandler.prototype;

  _proto.zoomIn = function zoomIn() {
    var zoomRatio = this.canvas.getZoom();
    zoomRatio += 0.05;
    var center = this.canvas.getCenter();
    this.zoomToPoint(new fabric.fabric.Point(center.left, center.top), zoomRatio);
    this.context.setZoomRatio(zoomRatio);
  };

  _proto.zoomOut = function zoomOut() {
    var zoomRatio = this.canvas.getZoom();
    zoomRatio -= 0.05;
    var center = this.canvas.getCenter();
    this.zoomToPoint(new fabric.fabric.Point(center.left, center.top), zoomRatio);
    this.context.setZoomRatio(zoomRatio);
  };

  _proto.zoomToOne = function zoomToOne() {
    var center = this.canvas.getCenter();
    this.canvas.setViewportTransform([1, 0, 0, 1, 0, 0]);
    this.zoomToPoint(new fabric.fabric.Point(center.left, center.top), 1);
    this.context.setZoomRatio(1);
  };

  _proto.zoomToFit = function zoomToFit() {
    var zoomFitRatio = this.handlers.frameHandler.getFitRatio();
    var center = this.canvas.getCenter();
    this.canvas.setViewportTransform([1, 0, 0, 1, 0, 0]);
    this.zoomToPoint(new fabric.fabric.Point(center.left, center.top), zoomFitRatio);
    this.context.setZoomRatio(zoomFitRatio);
  };

  _proto.zoomToRatio = function zoomToRatio(zoomRatio) {
    var center = this.canvas.getCenter();
    this.zoomToPoint(new fabric.fabric.Point(center.left, center.top), zoomRatio);
    this.context.setZoomRatio(zoomRatio);
  };

  _proto.zoomToPoint = function zoomToPoint(point, zoom) {
    var minZoom = 10;
    var maxZoom = 300;
    var zoomRatio = zoom;

    if (zoom <= minZoom / 100) {
      zoomRatio = minZoom / 100;
    } else if (zoom >= maxZoom / 100) {
      zoomRatio = maxZoom / 100;
    }

    this.canvas.zoomToPoint(point, zoomRatio);
    this.context.setZoomRatio(zoomRatio);
  };

  return ZoomHandler;
}(BaseHandler);

function drawCircleIcon(ctx, left, top, __styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 5;
  ctx.arc(0, 0, 5, 0, 2 * Math.PI);
  ctx.strokeStyle = '#3782F7';
  ctx.stroke();
  ctx.fillStyle = '#ffffff';
  ctx.fill();
  ctx.restore();
}
function drawVerticalLineIcon(ctx, left, top, _styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  drawRectRounded(ctx, -2, -14, 4, 18, 2);
  ctx.lineWidth = 4;
  ctx.strokeStyle = '#3782F7';
  ctx.stroke();
  ctx.fillStyle = '#ffffff';
  ctx.fill();
  ctx.restore();
}

function drawRectRounded(ctx, x, y, w, h, radius) {
  ctx.beginPath();
  ctx.moveTo(x + radius, y);
  ctx.arcTo(x + w, y, x + w, y + h, radius);
  ctx.arcTo(x + w, y + h, x, y + h, radius);
  ctx.arcTo(x, y + h, x, y, radius);
  ctx.arcTo(x, y, x + w, y, radius);
  ctx.closePath();
}

function drawHorizontalLineIcon(ctx, left, top, _styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  drawRectRounded(ctx, -14, -2, 18, 4, 2);
  ctx.lineWidth = 4;
  ctx.strokeStyle = '#3782F7';
  ctx.stroke();
  ctx.fillStyle = '#ffffff';
  ctx.fill();
  ctx.restore();
}
function drawRotateIcon(ctx, left, top, _styleOverride, _fabricObject) {
  var radius = 6;
  var lineWidth = radius / 3;
  var arrowWidth = radius / 2;
  var center = {
    x: left,
    y: top
  };
  var arrow1 = {
    startAngle: 1 / 2 * Math.PI + 0.6,
    endAngle: 3 / 2 * Math.PI
  };
  var arrow2 = {
    startAngle: 3 / 2 * Math.PI + 0.6,
    endAngle: 1 / 2 * Math.PI
  };

  function draw(startAngle, endAngle) {
    ctx.beginPath();
    ctx.shadowBlur = 0;
    ctx.arc(center.x, center.y, radius, startAngle, endAngle);
    ctx.lineWidth = lineWidth;
    ctx.strokeStyle = '#000000';
    ctx.stroke();
    ctx.beginPath();
    var arrowTop = getPointOnCircle(center, radius, endAngle + 0.4);
    ctx.moveTo(arrowTop.x, arrowTop.y);
    var arrowLeft = getPointOnCircle(center, radius - arrowWidth, endAngle);
    ctx.lineTo(arrowLeft.x, arrowLeft.y);
    var arrowRight = getPointOnCircle(center, radius + arrowWidth, endAngle);
    ctx.lineTo(arrowRight.x, arrowRight.y);
    ctx.fillStyle = '#000000';
    ctx.closePath();
    ctx.fill();
  }

  function getPointOnCircle(center, radius, angle) {
    var pX = center.x + Math.cos(angle) * radius;
    var pY = center.y + Math.sin(angle) * radius;
    return {
      x: pX,
      y: pY
    };
  }

  ctx.save();
  ctx.translate(0, 0);
  ctx.beginPath();
  ctx.arc(center.x, center.y, radius + 6, 0, Math.PI * 2);
  ctx.fillStyle = '#ffffff';
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.fill();
  ctx.closePath();
  draw(arrow1.startAngle, arrow1.endAngle);
  draw(arrow2.startAngle, arrow2.endAngle);
  ctx.restore();
}

var PersonalizationHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(PersonalizationHandler, _BaseHandler);

  function PersonalizationHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.init();

    return _this;
  }

  var _proto = PersonalizationHandler.prototype;

  _proto.init = function init() {
    var _this2 = this;

    //Disable context menu
    //@ts-ignore
    fabric.fabric.util.addListener(document.getElementsByClassName('upper-canvas')[0], 'contextmenu', function (e) {
      e.preventDefault();
    });
    fabric.fabric.Object.prototype.transparentCorners = false;
    fabric.fabric.Object.prototype.cornerColor = '#20bf6b';
    fabric.fabric.Object.prototype.cornerStyle = 'circle';
    fabric.fabric.Object.prototype.borderColor = '#3782F7';
    fabric.fabric.Object.prototype.cornerSize = 12;
    fabric.fabric.Object.prototype.borderScaleFactor = 2.75;
    fabric.fabric.Object.prototype.borderOpacityWhenMoving = 0;
    fabric.fabric.Object.prototype.borderOpacity = 1;
    fabric.fabric.Object.prototype.controls.tr = new fabric.fabric.Control({
      x: 0.5,
      y: -0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingEqually,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawCircleIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.tl = new fabric.fabric.Control({
      x: -0.5,
      y: -0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingEqually,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawCircleIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.bl = new fabric.fabric.Control({
      x: -0.5,
      y: 0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingEqually,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawCircleIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.br = new fabric.fabric.Control({
      x: 0.5,
      y: 0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingEqually,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawCircleIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.ml = new fabric.fabric.Control({
      x: -0.5,
      y: 0,
      actionHandler: fabric.fabric.controlsUtils.scalingXOrSkewingY,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawVerticalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.mt = new fabric.fabric.Control({
      x: 0,
      y: -0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingYOrSkewingX,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawHorizontalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.mb = new fabric.fabric.Control({
      x: 0,
      y: 0.5,
      actionHandler: fabric.fabric.controlsUtils.scalingYOrSkewingX,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawHorizontalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.mr = new fabric.fabric.Control({
      x: 0.5,
      y: 0,
      actionHandler: fabric.fabric.controlsUtils.scalingXOrSkewingY,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: fabric.fabric.controlsUtils.scaleOrSkewActionName,
      render: drawVerticalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Object.prototype.controls.mtr = new fabric.fabric.Control({
      x: 0,
      y: -0.5,
      offsetY: -40,
      actionHandler: fabric.fabric.controlsUtils.rotationWithSnapping,
      cursorStyleHandler: fabric.fabric.controlsUtils.rotationStyleHandler,
      actionName: 'rotate',
      render: drawRotateIcon,
      cornerSize: 28,
      withConnection: false
    }); // Texbox controls

    fabric.fabric.Textbox.prototype.controls.tr = fabric.fabric.Object.prototype.controls.tr;
    fabric.fabric.Textbox.prototype.controls.tl = fabric.fabric.Object.prototype.controls.tl;
    fabric.fabric.Textbox.prototype.controls.bl = fabric.fabric.Object.prototype.controls.bl;
    fabric.fabric.Textbox.prototype.controls.br = fabric.fabric.Object.prototype.controls.br;
    fabric.fabric.Textbox.prototype.controls.mt = new fabric.fabric.Control({
      render: function render() {
        return false;
      }
    });
    fabric.fabric.Textbox.prototype.controls.mb = fabric.fabric.Textbox.prototype.controls.mt;
    fabric.fabric.Textbox.prototype.controls.mr = new fabric.fabric.Control({
      x: 0.5,
      y: 0,
      actionHandler: fabric.fabric.controlsUtils.changeWidth,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: 'resizing',
      render: drawVerticalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Textbox.prototype.controls.ml = new fabric.fabric.Control({
      x: -0.5,
      y: 0,
      actionHandler: fabric.fabric.controlsUtils.changeWidth,
      cursorStyleHandler: fabric.fabric.controlsUtils.scaleSkewCursorStyleHandler,
      actionName: 'resizing',
      render: drawVerticalLineIcon,
      cornerSize: 28,
      withConnection: true
    });
    fabric.fabric.Textbox.prototype.controls.mtr = new fabric.fabric.Control({
      x: 0,
      y: -0.5,
      offsetY: -40,
      actionHandler: fabric.fabric.controlsUtils.rotationWithSnapping,
      cursorStyleHandler: fabric.fabric.controlsUtils.rotationStyleHandler,
      actionName: 'rotate',
      render: drawRotateIcon,
      cornerSize: 28,
      withConnection: false
    });
    this.canvas.selectionColor = 'rgba(55, 130, 247, 0.15)';
    this.canvas.selectionBorderColor = '#3782F7';
    this.canvas.selectionLineWidth = 1.5;
    this.canvas.on('selection:created', function (ev) {
      var objects = _this2.canvas.getActiveObjects();

      if (objects.length > 1) {
        ev.target.setControlsVisibility({
          mt: false,
          mb: false,
          mr: false,
          ml: false
        });
        ev.target.borderDashArray = [7];
      }
    });
    this.canvas.on('mouse:over', function (event) {
      var target = event.target;

      var activeObjects = _this2.canvas.getActiveObject();

      if (target && activeObjects !== target && target.type !== 'Background') {
        var bound = target.getBoundingRect();

        var ctx = _this2.canvas.getContext();

        ctx.strokeStyle = '#3782F7';
        ctx.lineWidth = 2.5;
        ctx.strokeRect(bound.left, bound.top, bound.width, bound.height);
      }
    });
  };

  return PersonalizationHandler;
}(BaseHandler);

var ExportObject = /*#__PURE__*/function (_ObjectType$STATIC_TE, _ObjectType$DYNAMIC_T, _ObjectType$STATIC_IM, _ObjectType$DYNAMIC_I, _ObjectType$STATIC_VE, _ObjectType$STATIC_PA, _ObjectType$BACKGROUN, _ObjectType$GROUP) {
  function ExportObject() {}

  var _proto = ExportObject.prototype;

  _proto.run = function run(item, options, inGroup) {
    if (inGroup === void 0) {
      inGroup = false;
    }

    var object;

    switch (item.type) {
      case ObjectType.STATIC_IMAGE:
        object = this[ObjectType.STATIC_IMAGE](item, options, inGroup);
        break;

      case ObjectType.STATIC_TEXT:
        object = this[ObjectType.STATIC_TEXT](item, options, inGroup);
        break;

      case ObjectType.STATIC_VECTOR:
        object = this[ObjectType.STATIC_VECTOR](item, options, inGroup);
        break;

      case ObjectType.STATIC_PATH:
        object = this[ObjectType.STATIC_PATH](item, options, inGroup);
        break;

      case ObjectType.DYNAMIC_TEXT:
        object = this[ObjectType.DYNAMIC_TEXT](item, options, inGroup);
        break;

      case ObjectType.DYNAMIC_IMAGE:
        object = this[ObjectType.DYNAMIC_IMAGE](item, options, inGroup);
        break;

      case ObjectType.BACKGROUND:
        object = this[ObjectType.BACKGROUND](item, options, inGroup);
        break;

      case ObjectType.GROUP:
        object = this[ObjectType.GROUP](item, options, inGroup);
        break;
    }

    return object;
  };

  _proto[_ObjectType$STATIC_TE] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);
    var fontFamily = item.fontFamily,
        textAlign = item.textAlign,
        fontSize = item.fontSize,
        fontWeight = item.fontWeight,
        charSpacing = item.charSpacing,
        lineHeight = item.lineHeight,
        fill = item.fill,
        text = item.text,
        angle = item.angle;

    var metadata = _extends({}, item.metadata, {
      angle: angle,
      fill: fill,
      fontWeight: fontWeight,
      charspacing: charSpacing,
      fontSize: fontSize,
      template: text,
      fontFamily: fontFamily,
      textAlign: textAlign,
      lineheight: lineHeight,
      text: item.text
    });

    var object = _extends({}, baseOptions, {
      metadata: metadata
    });

    return object;
  };

  _proto[_ObjectType$DYNAMIC_T] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);
    var fontFamily = item.fontFamily,
        textAlign = item.textAlign,
        fontSize = item.fontSize,
        fontWeight = item.fontWeight,
        charSpacing = item.charSpacing,
        lineHeight = item.lineHeight,
        fill = item.fill,
        angle = item.angle,
        originalText = item.originalText,
        keyValues = item.keyValues;

    var metadata = _extends({}, item.metadata, {
      angle: angle,
      fill: fill,
      fontWeight: fontWeight,
      charSpacing: charSpacing,
      fontSize: fontSize,
      text: originalText,
      fontFamily: fontFamily,
      textAlign: textAlign,
      lineHeight: lineHeight,
      keyValues: keyValues,
      keys: item.keys ? item.keys : []
    });

    var object = _extends({}, baseOptions, {
      metadata: metadata
    });

    return object;
  };

  _proto[_ObjectType$STATIC_IM] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);

    var object = _extends({}, baseOptions, {
      metadata: {
        src: item.src,
        cropX: item.cropX,
        cropY: item.cropY
      }
    });

    return object;
  };

  _proto[_ObjectType$DYNAMIC_I] = function (item, options, inGroup) {
    var width = item.width,
        height = item.height,
        angle = item.angle,
        keyValues = item.keyValues,
        scaleX = item.scaleX,
        scaleY = item.scaleY;
    var baseOptions = this.getBaseOptions(item, options, inGroup);
    var metadata = {
      originX: item.originX,
      originY: item.originY,
      angle: angle,
      width: width,
      height: height,
      keyValues: keyValues,
      keys: item.keys ? item.keys : []
    };

    var object = _extends({}, baseOptions, {
      width: width * scaleX,
      height: height * scaleY,
      scaleX: 1,
      scaleY: 1,
      metadata: metadata
    });

    return object;
  };

  _proto[_ObjectType$STATIC_VE] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);

    var object = _extends({}, baseOptions, {
      metadata: {
        src: item.src
      }
    });

    return object;
  };

  _proto[_ObjectType$STATIC_PA] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);

    var object = _extends({}, baseOptions, {
      metadata: {
        value: item.path,
        fill: item.fill
      }
    });

    return object;
  };

  _proto[_ObjectType$BACKGROUN] = function (item, options, inGroup) {
    var baseOptions = this.getBaseOptions(item, options, inGroup);

    var object = _extends({}, baseOptions, {
      metadata: {
        fill: item.fill
      }
    });

    return object;
  };

  _proto[_ObjectType$GROUP] = function (item, options, inGroup) {
    var _this = this;

    var baseOptions = this.getBaseOptions(item, options, inGroup);
    var groupObjects = item.objects.map(function (object) {
      return _this.run(object, options, true);
    });
    return _extends({}, baseOptions, {
      objects: groupObjects
    });
  };

  _proto.getBaseOptions = function getBaseOptions(item, options, inGroup) {
    if (inGroup === void 0) {
      inGroup = false;
    }

    var id = item.id,
        name = item.name,
        top = item.top,
        left = item.left,
        width = item.width,
        height = item.height,
        scaleX = item.scaleX,
        scaleY = item.scaleY,
        originX = item.originX,
        originY = item.originY,
        type = item.type,
        stroke = item.stroke,
        strokeWidth = item.strokeWidth,
        opacity = item.opacity,
        angle = item.angle,
        flipX = item.flipX,
        flipY = item.flipY,
        skewX = item.skewX,
        skewY = item.skewY,
        visible = item.visible,
        animation = item.animation;
    var baseOptions = {
      id: id,
      name: name,
      angle: angle,
      stroke: stroke,
      strokeWidth: strokeWidth,
      left: inGroup ? left : left - options.left,
      top: inGroup ? top : top - options.top,
      width: width,
      height: height,
      opacity: opacity,
      originX: originX,
      originY: originY,
      scaleX: scaleX,
      scaleY: scaleY,
      type: type,
      flipX: flipX,
      flipY: flipY,
      skewX: skewX,
      skewY: skewY,
      visible: visible,
      animation: animation
    };
    return baseOptions;
  };

  return ExportObject;
}(ObjectType.STATIC_TEXT, ObjectType.DYNAMIC_TEXT, ObjectType.STATIC_IMAGE, ObjectType.DYNAMIC_IMAGE, ObjectType.STATIC_VECTOR, ObjectType.STATIC_PATH, ObjectType.BACKGROUND, ObjectType.GROUP);

var exportObject = /*#__PURE__*/new ExportObject();

var TemplateHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(TemplateHandler, _BaseHandler);

  function TemplateHandler() {
    return _BaseHandler.apply(this, arguments) || this;
  }

  var _proto = TemplateHandler.prototype;

  _proto.exportToJSON = function exportToJSON() {
    var animated = false;
    var canvasJSON = this.canvas.toJSON(this.handlers.propertiesToInclude);
    var frameOptions = this.handlers.frameHandler.getOptions();
    var template = {
      name: 'Untitled design',
      objects: [],
      background: {
        type: 'color',
        value: frameOptions.fill ? frameOptions.fill : '#fff'
      },
      frame: {
        width: frameOptions.width,
        height: frameOptions.height
      },
      metadata: {
        animated: animated
      }
    };
    var objects = canvasJSON.objects.filter(function (object) {
      return object.type !== ObjectType.FRAME;
    });
    objects.forEach(function (object) {
      var exportedObject = exportObject.run(object, frameOptions);
      template.objects = template.objects.concat(exportedObject);

      if (object.animations && object.animations !== 'NONE') {
        animated = true;
      }
    });
    template.metadata = _extends({}, template.metadata, {
      animated: animated
    });
    return template;
  };

  _proto.importFromJSON = /*#__PURE__*/function () {
    var _importFromJSON = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(template) {
      var frameParams, frameOptions, _iterator, _step, object, element, frame;

      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              this.handlers.objectsHandler.clear();
              frameParams = template.frame;
              this.handlers.frameHandler.setSize(frameParams);
              frameOptions = this.handlers.frameHandler.getOptions();
              _iterator = _createForOfIteratorHelperLoose(template.objects);

            case 5:
              if ((_step = _iterator()).done) {
                _context.next = 13;
                break;
              }

              object = _step.value;
              _context.next = 9;
              return objectToFabric.run(object, frameOptions);

            case 9:
              element = _context.sent;

              if (element) {
                if (this.config.clipToFrame) {
                  frame = this.handlers.frameHandler.getFrame();
                  element.clipPath = frame;
                }

                this.canvas.add(element);
              } else {
                console.log('UNABLE TO LOAD OBJECT: ', object);
              }

            case 11:
              _context.next = 5;
              break;

            case 13:
              this.handlers.frameHandler.setBackgroundColor(template.background && template.background.type === 'color' ? template.background.value : '#ffffff');
              this.handlers.historyHandler.save('template:load');
              this.handlers.historyHandler.clear();
              this.handlers.zoomHandler.zoomToFit();
              this.handlers.animationHandler.setTemplateAnimations();

            case 18:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function importFromJSON(_x) {
      return _importFromJSON.apply(this, arguments);
    }

    return importFromJSON;
  }();

  return TemplateHandler;
}(BaseHandler);

var ScrollbarHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(ScrollbarHandler, _BaseHandler);

  function ScrollbarHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.initialize = function () {
      _this.diffBottom = 0;
      _this.diffLeft = 0;
      _this.diffRight = 0;
      _this.diffTop = 0;

      _this.canvas.on('mouse:wheel', _this.onMouseWheel);

      _this.initializeScrollY();

      _this.initializeScrollX();
    };

    _this.destroy = function () {
      var scrollbarY = document.getElementById('scrollbarY');

      _this.canvas.off('mouse:wheel', _this.onMouseWheel);

      scrollbarY.removeEventListener('mousedown', _this.scrollbarYMouseDown);
    };

    _this.onMouseWheel = function (event) {
      var isCtrlKey = event.e.ctrlKey;

      if (!isCtrlKey) {
        _this.handlePan(event);
      }

      _this.updateScrollPosition();
    };

    _this.handlePan = function (event) {
      var delta = event.e.deltaY;
      var isShiftKey = event.e.shiftKey;
      var change = delta > 0 ? 10 : -10;

      if (isShiftKey) {
        _this.handleScrollX(change);
      } else {
        _this.handleScrollY(change);
      }
    };

    _this.handleScrollX = function (delta) {
      if (delta > 0) {
        if (_this.diffRight > _this.config.scrollLimit) {
          return;
        }
      } else {
        if (_this.diffLeft > _this.config.scrollLimit) {
          return;
        }
      }

      var pointX = -delta;
      var pointY = 0;
      var point = new fabric.fabric.Point(pointX, pointY);

      _this.canvas.relativePan(point);

      _this.updateScrollPosition();
    };

    _this.handleScrollY = function (delta) {
      if (delta > 0) {
        if (_this.diffBottom > _this.config.scrollLimit) {
          return;
        }
      } else {
        if (_this.diffTop > _this.config.scrollLimit) {
          return;
        }
      }

      var pointX = 0;
      var pointY = -delta;
      var point = new fabric.fabric.Point(pointX, pointY);

      _this.canvas.relativePan(point);

      _this.updateScrollPosition();
    };

    _this.updateScrollPosition = function () {
      _this.calculateScrollBottom();

      _this.calculateScrollRight();

      _this.calculateScrollY();

      _this.calculateScrollX();
    };

    _this.initializeScrollY = function () {
      var container = document.getElementById('scenify-editor-container');
      var scrollbarContainer = document.createElement('div');
      var scrollbarWrapper = document.createElement('div');
      var scrollbar = document.createElement('div');
      scrollbar.addEventListener('mousedown', _this.scrollbarYMouseDown);
      scrollbar.setAttribute('id', 'scrollbarY');

      _this.setElementStyle(scrollbarContainer, {
        position: 'absolute',
        right: '5px',
        height: '100%',
        display: 'flex',
        alignItems: 'center'
      });

      _this.setElementStyle(scrollbarWrapper, {
        position: 'relative',
        height: 'calc(100% - 30px)',
        width: '6px',
        overflow: 'hidden',
        margin: 'auto'
      });

      _this.setElementStyle(scrollbar, {
        position: 'absolute',
        width: '6px',
        background: 'rgba(0,0,0,0.4)',
        height: '0px',
        top: '125px',
        borderRadius: '5px'
      });

      scrollbarContainer.appendChild(scrollbarWrapper);
      scrollbarWrapper.appendChild(scrollbar);
      container.appendChild(scrollbarContainer);
    };

    _this.scrollbarYMouseDown = function () {
      document.addEventListener('mousemove', _this.scrollbarYMouseMove);
      document.addEventListener('mouseup', _this.scrollbarYMouseUp);
    };

    _this.scrollbarYMouseUp = function () {
      document.removeEventListener('mousemove', _this.scrollbarYMouseMove);
      document.removeEventListener('mouseup', _this.scrollbarYMouseUp);
    };

    _this.scrollbarYMouseMove = function (e) {
      var delta = e.movementY;
      var change = delta > 0 ? 5 : -5;

      _this.handleScrollY(change);
    };

    _this.initializeScrollX = function () {
      var container = document.getElementById('scenify-editor-container');
      var scrollbarContainer = document.createElement('div');
      var scrollbarWrapper = document.createElement('div');
      var scrollbar = document.createElement('div');
      scrollbar.addEventListener('mousedown', _this.scrollbarXMouseDown);
      scrollbar.setAttribute('id', 'scrollbarX');

      _this.setElementStyle(scrollbarContainer, {
        position: 'absolute',
        bottom: '5px',
        width: '100%',
        display: 'flex',
        alignItems: 'center'
      });

      _this.setElementStyle(scrollbarWrapper, {
        position: 'relative',
        width: 'calc(100% - 30px)',
        height: '6px',
        overflow: 'hidden',
        margin: 'auto'
      });

      _this.setElementStyle(scrollbar, {
        position: 'absolute',
        width: '600px',
        background: 'rgba(0,0,0,0.4)',
        height: '6px',
        left: '125px',
        borderRadius: '5px'
      });

      scrollbarContainer.appendChild(scrollbarWrapper);
      scrollbarWrapper.appendChild(scrollbar);
      container.appendChild(scrollbarContainer);
    };

    _this.scrollbarXMouseDown = function () {
      document.addEventListener('mousemove', _this.scrollbarXMouseMove);
      document.addEventListener('mouseup', _this.scrollbarXMouseUp);
    };

    _this.scrollbarXMouseUp = function () {
      document.removeEventListener('mousemove', _this.scrollbarXMouseMove);
      document.removeEventListener('mouseup', _this.scrollbarXMouseUp);
    };

    _this.scrollbarXMouseMove = function (e) {
      var delta = e.movementX;
      var change = delta > 0 ? 5 : -5;

      _this.handleScrollX(change);
    };

    _this.setElementStyle = function (element, styles) {
      Object.keys(styles).forEach(function (style) {
        element.style[style] = styles[style];
      });
    };

    _this.initialize();

    return _this;
  }

  var _proto = ScrollbarHandler.prototype;

  _proto.calculateScrollY = function calculateScrollY() {
    var canvasHeight = this.canvas.getHeight();
    var scrollbarY = document.getElementById('scrollbarY');
    var diffTop = this.diffTop,
        diffBottom = this.diffBottom;

    if (diffTop > 0 && diffBottom > 0) {
      scrollbarY.style.height = '0px';
    } else if (diffTop > 0 && diffBottom < 0) {
      var bottom = diffBottom;
      var calculatedSize = canvasHeight + diffBottom;

      if (canvasHeight / 2 + diffBottom < 100) {
        calculatedSize = 100;
        this.setElementStyle(scrollbarY, {
          bottom: 'auto',
          top: 0 + 'px',
          height: calculatedSize + 'px'
        });
      } else {
        this.setElementStyle(scrollbarY, {
          bottom: 'auto',
          top: bottom + 'px',
          height: calculatedSize + 'px'
        });
      }
    } else if (diffTop < 0 && diffBottom < 0) {
      var _calculatedSize = canvasHeight + diffBottom + diffTop;

      _calculatedSize = _calculatedSize > 100 ? _calculatedSize : 100;
      this.setElementStyle(scrollbarY, {
        bottom: 'auto',
        top: Math.abs(diffTop) + 'px',
        height: _calculatedSize + 'px'
      });
    } else if (diffTop < 0 && diffBottom > 0) {
      var _calculatedSize2 = canvasHeight + diffTop;

      this.setElementStyle(scrollbarY, {
        top: 'auto',
        bottom: diffTop + 'px',
        height: _calculatedSize2 + 'px'
      });
    }
  };

  _proto.calculateScrollBottom = function calculateScrollBottom() {
    var frame = this.handlers.frameHandler.getFrame();
    var zoomRatio = this.canvas.getZoom();
    var canvasHeight = this.canvas.getHeight();
    var canvasCenter = this.canvas.getCenter();
    var panningOffset = canvasCenter.top - (frame.top + frame.height / 2) * zoomRatio;
    var pannintTop = this.canvas.viewportTransform[5] - panningOffset;
    var availableSpace = canvasHeight - frame.height * zoomRatio;
    var verticalOffset = availableSpace / 2;
    var offsetBottom = verticalOffset - pannintTop;
    var offsetTop = verticalOffset + pannintTop;
    this.diffTop = offsetTop;
    this.diffBottom = offsetBottom;
  };

  _proto.calculateScrollX = function calculateScrollX() {
    var canvasWidth = this.canvas.getWidth();
    var scrollbarX = document.getElementById('scrollbarX');
    var diffLeft = this.diffLeft,
        diffRight = this.diffRight;

    if (diffLeft > 0 && diffRight > 0) {
      scrollbarX.style.width = '0px';
    } else if (diffLeft > 0 && diffRight < 0) {
      var calculatedSize = canvasWidth + diffRight;

      if (canvasWidth / 2 + diffRight < 100) {
        calculatedSize = 100;
        this.setElementStyle(scrollbarX, {
          right: 'auto',
          left: 0 + 'px',
          width: calculatedSize + 'px'
        });
      } else {
        this.setElementStyle(scrollbarX, {
          right: 'auto',
          left: diffRight + 'px',
          width: calculatedSize + 'px'
        });
      }
    } else if (diffLeft < 0 && diffRight < 0) {
      var _calculatedSize3 = canvasWidth + diffLeft + diffRight;

      _calculatedSize3 = _calculatedSize3 > 100 ? _calculatedSize3 : 100;
      this.setElementStyle(scrollbarX, {
        right: 'auto',
        left: Math.abs(diffLeft) + 'px',
        width: _calculatedSize3 + 'px'
      });
    } else if (diffLeft < 0 && diffRight > 0) {
      var _calculatedSize4 = canvasWidth + diffLeft;

      this.setElementStyle(scrollbarX, {
        left: 'auto',
        right: diffLeft + 'px',
        width: _calculatedSize4 + 'px'
      });
    }
  };

  _proto.calculateScrollRight = function calculateScrollRight() {
    var frame = this.handlers.frameHandler.getFrame();
    var zoomRatio = this.canvas.getZoom();
    var canvasWidth = this.canvas.getWidth();
    var canvasCenter = this.canvas.getCenter();
    var panningOffset = canvasCenter.left - (frame.left + frame.width / 2) * zoomRatio;
    var pannintLeft = this.canvas.viewportTransform[4] - panningOffset;
    var availableSpace = canvasWidth - frame.width * zoomRatio;
    var horizontalOffset = availableSpace / 2;
    var offsetRight = horizontalOffset - pannintLeft;
    var offsetLeft = horizontalOffset + pannintLeft;
    this.diffLeft = offsetLeft;
    this.diffRight = offsetRight;
  };

  return ScrollbarHandler;
}(BaseHandler);

var REGEX_VAR = /*#__PURE__*/new RegExp(/\{\{[a-zA-Z0-9-_]+?\}\}/g);
function replaceKeyWithValue(text, _keys, params) {
  function replaces() {
    var matches = text.matchAll(REGEX_VAR);
    var pieces = '';

    for (var _iterator = _createForOfIteratorHelperLoose(matches), _step; !(_step = _iterator()).done;) {
      var match = _step.value;
      var startIndex = match['index'];
      var matchWord = match['0'];

      {
        var initialSection = text.slice(0, startIndex);
        pieces = pieces + initialSection;
      }

      var updatedValue = params[matchWord.substring(2, matchWord.length - 2)] ? params[matchWord.substring(2, matchWord.length - 2)] : matchWord.substring(2, matchWord.length - 2);
      pieces = pieces + updatedValue;
      var lastPiece = text.slice(startIndex + matchWord.length, text.length);
      text = pieces + lastPiece;
      replaces();
      return false;
    }

    return text;
  }

  replaces();
  return text;
}

var ObjectToFabric$1 = /*#__PURE__*/function (_ObjectType$STATIC_TE, _ObjectType$DYNAMIC_T, _ObjectType$STATIC_IM, _ObjectType$DYNAMIC_I, _ObjectType$STATIC_PA, _ObjectType$GROUP, _ObjectType$BACKGROUN, _ObjectType$STATIC_VE) {
  function ObjectToFabric() {}

  var _proto = ObjectToFabric.prototype;

  _proto.run = /*#__PURE__*/function () {
    var _run = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(item, params) {
      var object;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.t0 = item.type;
              _context.next = _context.t0 === ObjectType.STATIC_TEXT ? 3 : _context.t0 === ObjectType.DYNAMIC_TEXT ? 7 : _context.t0 === ObjectType.STATIC_IMAGE ? 11 : _context.t0 === ObjectType.DYNAMIC_IMAGE ? 15 : _context.t0 === ObjectType.STATIC_VECTOR ? 19 : _context.t0 === ObjectType.STATIC_PATH ? 23 : _context.t0 === ObjectType.BACKGROUND ? 27 : _context.t0 === ObjectType.GROUP ? 31 : 35;
              break;

            case 3:
              _context.next = 5;
              return this[ObjectType.STATIC_TEXT](item);

            case 5:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 7:
              _context.next = 9;
              return this[ObjectType.DYNAMIC_TEXT](item, params);

            case 9:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 11:
              _context.next = 13;
              return this[ObjectType.STATIC_IMAGE](item);

            case 13:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 15:
              _context.next = 17;
              return this[ObjectType.DYNAMIC_IMAGE](item, params);

            case 17:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 19:
              _context.next = 21;
              return this[ObjectType.STATIC_VECTOR](item);

            case 21:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 23:
              _context.next = 25;
              return this[ObjectType.STATIC_PATH](item);

            case 25:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 27:
              _context.next = 29;
              return this[ObjectType.BACKGROUND](item);

            case 29:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 31:
              _context.next = 33;
              return this[ObjectType.GROUP](item, params);

            case 33:
              object = _context.sent;
              return _context.abrupt("break", 35);

            case 35:
              return _context.abrupt("return", object);

            case 36:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function run(_x, _x2) {
      return _run.apply(this, arguments);
    }

    return run;
  }();

  _proto[_ObjectType$STATIC_TE] = function (item) {
    var _this = this;

    return new Promise(function (resolve, reject) {
      try {
        var baseOptions = _this.getBaseOptions(item);

        var metadata = item.metadata;
        var textAlign = metadata.textAlign,
            fontFamily = metadata.fontFamily,
            fontSize = metadata.fontSize,
            fontWeight = metadata.fontWeight,
            charSpacing = metadata.charSpacing,
            lineheight = metadata.lineheight,
            text = metadata.text;

        var textOptions = _extends({}, baseOptions, {
          text: text ? text : 'Default Text'
        }, textAlign && {
          textAlign: textAlign
        }, fontFamily && {
          fontFamily: fontFamily
        }, fontSize && {
          fontSize: fontSize
        }, fontWeight && {
          fontWeight: fontWeight
        }, charSpacing && {
          charSpacing: charSpacing
        }, lineheight && {
          lineheight: lineheight
        });

        var element = new fabric.fabric.StaticText(textOptions);
        resolve(element);
      } catch (err) {
        reject(err);
      }
    });
  };

  _proto[_ObjectType$DYNAMIC_T] = function (item, params) {
    var _this2 = this;

    return new Promise(function (resolve, reject) {
      try {
        var baseOptions = _this2.getBaseOptions(item);

        var metadata = item.metadata;
        var textAlign = metadata.textAlign,
            fontFamily = metadata.fontFamily,
            fontSize = metadata.fontSize,
            fontWeight = metadata.fontWeight,
            charSpacing = metadata.charSpacing,
            lineheight = metadata.lineheight,
            text = metadata.text,
            keys = metadata.keys;
        var updatedText = replaceKeyWithValue(text, keys, params);

        var textOptions = _extends({}, baseOptions, {
          text: updatedText ? updatedText : 'Default Text'
        }, textAlign && {
          textAlign: textAlign
        }, fontFamily && {
          fontFamily: fontFamily
        }, fontSize && {
          fontSize: fontSize
        }, fontWeight && {
          fontWeight: fontWeight
        }, charSpacing && {
          charSpacing: charSpacing
        }, lineheight && {
          lineheight: lineheight
        });

        var element = new fabric.fabric.StaticText(textOptions);
        resolve(element);
      } catch (err) {
        reject(err);
      }
    });
  };

  _proto[_ObjectType$STATIC_IM] = function (item) {
    var _this3 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(resolve, reject) {
        var baseOptions, src, image, element;
        return runtime_1.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.prev = 0;
                baseOptions = _this3.getBaseOptions(item);
                src = item.metadata.src;
                _context2.next = 5;
                return loadImageFromURL(src);

              case 5:
                image = _context2.sent;
                element = new fabric.fabric.StaticImage(image, _extends({}, baseOptions, {
                  cropX: 0,
                  cropY: item.metadata.cropY
                }));
                resolve(element);
                _context2.next = 13;
                break;

              case 10:
                _context2.prev = 10;
                _context2.t0 = _context2["catch"](0);
                reject(_context2.t0);

              case 13:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, null, [[0, 10]]);
      }));

      return function (_x3, _x4) {
        return _ref.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$DYNAMIC_I] = function (item, params) {
    var _this4 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(resolve, reject) {
        var baseOptions, src, image, element;
        return runtime_1.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                baseOptions = _this4.getBaseOptions(item);
                src = params.image;
                _context3.next = 5;
                return loadImageFromURL(src);

              case 5:
                image = _context3.sent;
                // @ts-ignore
                element = new fabric.fabric.StaticImage(image, _extends({}, baseOptions, {
                  // @ts-ignore
                  width: image.width,
                  // @ts-ignore
                  height: image.height,
                  cropX: 0,
                  cropY: 0 // scaleX: 0.2

                }));
                element.scaleToWidth(item.width);
                resolve(element);
                _context3.next = 14;
                break;

              case 11:
                _context3.prev = 11;
                _context3.t0 = _context3["catch"](0);
                reject(_context3.t0);

              case 14:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3, null, [[0, 11]]);
      }));

      return function (_x5, _x6) {
        return _ref2.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$STATIC_PA] = function (item) {
    var _this5 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref3 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee4(resolve, reject) {
        var baseOptions, value, element;
        return runtime_1.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                try {
                  baseOptions = _this5.getBaseOptions(item);
                  value = item.metadata.value;
                  element = new fabric.fabric.Path(value, baseOptions);
                  resolve(element);
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context4.stop();
            }
          }
        }, _callee4);
      }));

      return function (_x7, _x8) {
        return _ref3.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$GROUP] = function (item, params) {
    var _this6 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref4 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee5(resolve, reject) {
        var baseOptions, objects, _iterator, _step, object, element;

        return runtime_1.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                _context5.prev = 0;
                baseOptions = _this6.getBaseOptions(item);
                objects = [];
                _iterator = _createForOfIteratorHelperLoose(item.objects);

              case 4:
                if ((_step = _iterator()).done) {
                  _context5.next = 13;
                  break;
                }

                object = _step.value;
                _context5.t0 = objects;
                _context5.next = 9;
                return _this6.run(object, params);

              case 9:
                _context5.t1 = _context5.sent;
                objects = _context5.t0.concat.call(_context5.t0, _context5.t1);

              case 11:
                _context5.next = 4;
                break;

              case 13:
                element = new fabric.fabric.Group(objects, baseOptions);
                resolve(element);
                _context5.next = 20;
                break;

              case 17:
                _context5.prev = 17;
                _context5.t2 = _context5["catch"](0);
                reject(_context5.t2);

              case 20:
              case "end":
                return _context5.stop();
            }
          }
        }, _callee5, null, [[0, 17]]);
      }));

      return function (_x9, _x10) {
        return _ref4.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$BACKGROUN] = function (item) {
    var _this7 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref5 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee6(resolve, reject) {
        var baseOptions, fill, element;
        return runtime_1.wrap(function _callee6$(_context6) {
          while (1) {
            switch (_context6.prev = _context6.next) {
              case 0:
                try {
                  baseOptions = _this7.getBaseOptions(item); // const path = item.metadata.value

                  fill = item.metadata.fill;
                  element = new fabric.fabric.Background(_extends({}, baseOptions, {
                    fill: fill ? fill : '#000000',
                    id: 'background',
                    name: ''
                  }));
                  resolve(element);
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context6.stop();
            }
          }
        }, _callee6);
      }));

      return function (_x11, _x12) {
        return _ref5.apply(this, arguments);
      };
    }());
  };

  _proto[_ObjectType$STATIC_VE] = function (item) {
    var _this8 = this;

    return new Promise( /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee7(resolve, reject) {
        var baseOptions, src;
        return runtime_1.wrap(function _callee7$(_context7) {
          while (1) {
            switch (_context7.prev = _context7.next) {
              case 0:
                try {
                  baseOptions = _this8.getBaseOptions(item);
                  src = item.metadata.src;
                  fabric.fabric.loadSVGFromURL(src, function (objects, opts) {
                    var width = baseOptions.width,
                        height = baseOptions.height;

                    if (!width || !height) {
                      baseOptions.width = opts.width;
                      baseOptions.height = opts.height;
                    }

                    var object = new fabric.fabric.StaticVector(objects, opts, _extends({}, baseOptions, {
                      src: src
                    }));
                    resolve(object);
                  });
                } catch (err) {
                  reject(err);
                }

              case 1:
              case "end":
                return _context7.stop();
            }
          }
        }, _callee7);
      }));

      return function (_x13, _x14) {
        return _ref6.apply(this, arguments);
      };
    }());
  };

  _proto.getBaseOptions = function getBaseOptions(item) {
    var left = item.left,
        top = item.top,
        width = item.width,
        height = item.height,
        scaleX = item.scaleX,
        scaleY = item.scaleY,
        opacity = item.opacity,
        flipX = item.flipX,
        flipY = item.flipY,
        skewX = item.skewX,
        skewY = item.skewY,
        stroke = item.stroke,
        strokeWidth = item.strokeWidth,
        animation = item.animation,
        originX = item.originX,
        originY = item.originY,
        angle = item.angle;
    var metadata = item.metadata ? item.metadata : {};
    var fill = metadata.fill;
    var baseOptions = {
      angle: angle,
      top: top,
      left: left,
      width: width,
      height: height,
      originX: originX || 'left',
      originY: originY || 'top',
      scaleX: scaleX || 1,
      scaleY: scaleY || 1,
      fill: fill || '#000000',
      opacity: opacity ? opacity : 1,
      flipX: flipX ? flipX : false,
      flipY: flipY ? flipY : false,
      skewX: skewX ? skewX : 0,
      skewY: skewY ? skewY : 0,
      metadata: metadata,
      stroke: stroke,
      strokeWidth: strokeWidth,
      animation: animation
    };
    return baseOptions;
  };

  return ObjectToFabric;
}(ObjectType.STATIC_TEXT, ObjectType.DYNAMIC_TEXT, ObjectType.STATIC_IMAGE, ObjectType.DYNAMIC_IMAGE, ObjectType.STATIC_PATH, ObjectType.GROUP, ObjectType.BACKGROUND, ObjectType.STATIC_VECTOR);

var objectToFabric$1 = /*#__PURE__*/new ObjectToFabric$1();

var DesignHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(DesignHandler, _BaseHandler);

  function DesignHandler() {
    return _BaseHandler.apply(this, arguments) || this;
  }

  var _proto = DesignHandler.prototype;

  _proto.toDataURL = /*#__PURE__*/function () {
    var _toDataURL = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(params) {
      var staticCanvas, template, data;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              staticCanvas = new fabric.fabric.StaticCanvas(null);
              template = this.handlers.templateHandler.exportToJSON();
              _context.next = 4;
              return this.loadTemplate(staticCanvas, template, params);

            case 4:
              data = staticCanvas.toDataURL({
                top: 0,
                left: 0,
                height: staticCanvas.getHeight(),
                width: staticCanvas.getWidth()
              });
              return _context.abrupt("return", data);

            case 6:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function toDataURL(_x) {
      return _toDataURL.apply(this, arguments);
    }

    return toDataURL;
  }();

  _proto.loadTemplate = /*#__PURE__*/function () {
    var _loadTemplate = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(staticCanvas, template, params) {
      var frame, background, _iterator, _step, object, element;

      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              frame = template.frame, background = template.background;
              this.setDimensions(staticCanvas, frame);
              this.setBackground(staticCanvas, background);
              _iterator = _createForOfIteratorHelperLoose(template.objects);

            case 4:
              if ((_step = _iterator()).done) {
                _context2.next = 12;
                break;
              }

              object = _step.value;
              _context2.next = 8;
              return objectToFabric$1.run(object, params);

            case 8:
              element = _context2.sent;

              if (element) {
                staticCanvas.add(element);
              } else {
                console.log('UNABLE TO LOAD OBJECT: ', object);
              }

            case 10:
              _context2.next = 4;
              break;

            case 12:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function loadTemplate(_x2, _x3, _x4) {
      return _loadTemplate.apply(this, arguments);
    }

    return loadTemplate;
  }();

  _proto.setDimensions = function setDimensions(staticCanvas, _ref) {
    var width = _ref.width,
        height = _ref.height;
    staticCanvas.setWidth(width).setHeight(height);
  };

  _proto.setBackground = function setBackground(staticCanvas, background) {
    if (!background) {
      return;
    }

    staticCanvas.setBackgroundColor(background.type === 'color' ? background.value : '#ffffff', function () {
      staticCanvas.renderAll();
    });
  };

  return DesignHandler;
}(BaseHandler);

// ANIMATIONS
var Animations;

(function (Animations) {
  Animations["NONE"] = "NONE";
  Animations["STOMP"] = "STOMP";
  Animations["TUMBLE"] = "TUMBLE";
  Animations["RISE"] = "RISE";
  Animations["PAN"] = "PAN";
  Animations["FADE"] = "FADE";
  Animations["BREATHE"] = "BREATHE";
})(Animations || (Animations = {}));

// @ts-nocheck

var renderer = function renderer(config) {
  return new Promise(function (resolve, reject) {
    try {
      var width = config.width,
          height = config.height,
          fps = config.fps,
          makeScene = config.makeScene,
          _config$silent = config.silent,
          silent = _config$silent === void 0 ? true : _config$silent;
      var canvas = new fabric.fabric.StaticCanvas(null, {
        width: width,
        height: height,
        backgroundColor: '#ffffff'
      });
      var anim = gsap__default.timeline();
      var frames = [];
      var totalFrames;
      var frameDuration = 0;
      var currentFrame = 0;
      gsap__default.ticker.fps(fps);

      var renderFrames = function renderFrames() {
        anim.progress(currentFrame++ / totalFrames);

        if (currentFrame <= totalFrames) {
          canvas.renderAll();
          frames.push(canvas.toDataURL());
          renderFrames();
        } else {
          resolve({
            frames: frames,
            frameDuration: frameDuration
          });
        }
      };

      makeScene(fabric.fabric, canvas, anim, function () {
        var duration = anim.duration();
        totalFrames = Math.max(1, Math.ceil(duration / 1 * fps));
        frameDuration = duration / totalFrames;
        renderFrames();
      });
    } catch (err) {
      console.log(err);
      reject(new Error('An error occured in the renderer.'));
    }
  });
};

var GifHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(GifHandler, _BaseHandler);

  function GifHandler() {
    var _this;

    _this = _BaseHandler.apply(this, arguments) || this;

    _this.framesToGif = function (images, options) {
      return new Promise(function (resolve, reject) {
        gifshot.createGIF({
          images: images,
          gifWidth: options.width,
          gifHeight: options.height,
          frameDuration: 0.0001
        }, function (obj) {
          if (!obj.error) {
            var image = obj.image;
            resolve(image);
          } else {
            reject(obj);
          }
        });
      });
    };

    _this.animateObject = function (object, animation, anim) {
      var _animations;

      var animations = (_animations = {}, _animations[Animations.NONE] = {}, _animations[Animations.TUMBLE] = {
        duration: 0.5,
        left: 0 - object.width,
        angle: 45,
        ease: gsap.Linear.easeInOut
      }, _animations[Animations.STOMP] = {
        duration: 1,
        ease: 'slow(0.7, 0.7, false)',
        scaleX: 1.5 * object.scaleX,
        scaleY: 1.5 * object.scaleY
      }, _animations[Animations.RISE] = {
        duration: 0.5,
        top: object.top + object.height * 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations[Animations.PAN] = {
        duration: 0.5,
        left: object.left - object.width * object.scaleX / 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations[Animations.FADE] = {
        duration: 1,
        opacity: 0,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations[Animations.BREATHE] = {
        duration: 1,
        scaleX: object.scaleX + object.scaleX / 2,
        scaleY: object.scaleY + object.scaleY / 2,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations);

      if (object && animations[animation]) {
        anim.from(object, _extends({}, animations[animation]), 0);
      }
    };

    return _this;
  }

  var _proto = GifHandler.prototype;

  _proto.toGif = /*#__PURE__*/function () {
    var _toGif = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(params) {
      var _this2 = this;

      var template, _yield$renderer, frames, frameDuration, gif;

      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              template = this.handlers.templateHandler.exportToJSON();
              _context2.next = 3;
              return renderer({
                silent: false,
                width: template.frame.width,
                height: template.frame.height,
                fps: 30,
                makeScene: function () {
                  var _makeScene = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(_, canvas, anim, compose) {
                    var _iterator, _step, object, element;

                    return runtime_1.wrap(function _callee$(_context) {
                      while (1) {
                        switch (_context.prev = _context.next) {
                          case 0:
                            _iterator = _createForOfIteratorHelperLoose(template.objects);

                          case 1:
                            if ((_step = _iterator()).done) {
                              _context.next = 9;
                              break;
                            }

                            object = _step.value;
                            _context.next = 5;
                            return objectToFabric$1.run(object, params);

                          case 5:
                            element = _context.sent;

                            if (element) {
                              canvas.add(element);

                              if (element.animation) {
                                _this2.animateObject(element, element.animation, anim);
                              }
                            } else {
                              console.log('UNABLE TO LOAD OBJECT: ', object);
                            }

                          case 7:
                            _context.next = 1;
                            break;

                          case 9:
                            compose();

                          case 10:
                          case "end":
                            return _context.stop();
                        }
                      }
                    }, _callee);
                  }));

                  function makeScene(_x2, _x3, _x4, _x5) {
                    return _makeScene.apply(this, arguments);
                  }

                  return makeScene;
                }()
              });

            case 3:
              _yield$renderer = _context2.sent;
              frames = _yield$renderer.frames;
              frameDuration = _yield$renderer.frameDuration;
              _context2.next = 8;
              return this.framesToGif(frames, {
                width: template.frame.width,
                height: template.frame.height,
                frameDuration: frameDuration
              });

            case 8:
              gif = _context2.sent;
              return _context2.abrupt("return", gif);

            case 10:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function toGif(_x) {
      return _toGif.apply(this, arguments);
    }

    return toGif;
  }();

  return GifHandler;
}(BaseHandler);

var GuidelinesHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(GuidelinesHandler, _BaseHandler);

  function GuidelinesHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;
    _this.viewportTransform = []; // this.ctx = this.canvas.getSelectionContext()

    _this.initAligningGuidelines(_this.canvas);

    return _this;
  }

  var _proto = GuidelinesHandler.prototype;

  _proto.initAligningGuidelines = function initAligningGuidelines(canvas) {
    var ctx = canvas.getSelectionContext(),
        aligningLineOffset = 5,
        aligningLineMargin = 4,
        aligningLineWidth = 1.5,
        aligningLineColor = '#e056fd',
        viewportTransform,
        zoom = canvas.getZoom();

    function drawVerticalLine(coords) {
      drawLine(coords.x + 0.5, coords.y1 > coords.y2 ? coords.y2 : coords.y1, coords.x + 0.5, coords.y2 > coords.y1 ? coords.y2 : coords.y1);
    }

    function drawHorizontalLine(coords) {
      drawLine(coords.x1 > coords.x2 ? coords.x2 : coords.x1, coords.y + 0.5, coords.x2 > coords.x1 ? coords.x2 : coords.x1, coords.y + 0.5);
    }

    function drawLine(x1, y1, x2, y2) {
      var vt = canvas.viewportTransform;
      ctx.save();
      ctx.lineWidth = aligningLineWidth;
      ctx.strokeStyle = aligningLineColor;
      ctx.beginPath();
      ctx.moveTo((x1 + viewportTransform[4] / vt[0]) * zoom, (y1 + viewportTransform[5] / vt[0]) * zoom);
      ctx.lineTo((x2 + viewportTransform[4] / vt[0]) * zoom, (y2 + viewportTransform[5] / vt[0]) * zoom);
      ctx.stroke();
      ctx.restore();
    }

    function isInRange(value1, value2) {
      value1 = Math.round(value1);
      value2 = Math.round(value2);

      for (var i = value1 - aligningLineMargin, len = value1 + aligningLineMargin; i <= len; i++) {
        if (i === value2) {
          return true;
        }
      }

      return false;
    }

    var verticalLines = [],
        horizontalLines = [];
    canvas.on('mouse:down', function () {
      viewportTransform = canvas.viewportTransform;
      zoom = canvas.getZoom();
    });
    canvas.on('object:moving', function (e) {
      var activeObject = e.target,
          canvasObjects = canvas.getObjects(),
          activeObjectCenter = activeObject.getCenterPoint(),
          activeObjectLeft = activeObjectCenter.x,
          activeObjectTop = activeObjectCenter.y,
          activeObjectBoundingRect = activeObject.getBoundingRect(),
          activeObjectHeight = activeObjectBoundingRect.height / viewportTransform[3],
          activeObjectWidth = activeObjectBoundingRect.width / viewportTransform[0],
          horizontalInTheRange = false,
          verticalInTheRange = false,
          transform = canvas._currentTransform;
      if (!transform) return; // It should be trivial to DRY this up by encapsulating (repeating) creation of x1, x2, y1, and y2 into functions,
      // but we're not doing it here for perf. reasons -- as this a function that's invoked on every mouse move

      for (var i = canvasObjects.length; i--;) {
        if (canvasObjects[i] === activeObject) continue;
        var objectCenter = canvasObjects[i].getCenterPoint(),
            objectLeft = objectCenter.x,
            objectTop = objectCenter.y,
            objectBoundingRect = canvasObjects[i].getBoundingRect(),
            objectHeight = objectBoundingRect.height / viewportTransform[3],
            objectWidth = objectBoundingRect.width / viewportTransform[0]; // snap by the horizontal center line

        if (isInRange(objectLeft, activeObjectLeft)) {
          verticalInTheRange = true;
          verticalLines.push({
            x: objectLeft,
            y1: objectTop < activeObjectTop ? objectTop - objectHeight / 2 - aligningLineOffset : objectTop + objectHeight / 2 + aligningLineOffset,
            y2: activeObjectTop > objectTop ? activeObjectTop + activeObjectHeight / 2 + aligningLineOffset : activeObjectTop - activeObjectHeight / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(objectLeft, activeObjectTop), 'center', 'center');
        } // snap by the left edge


        if (isInRange(objectLeft - objectWidth / 2, activeObjectLeft - activeObjectWidth / 2)) {
          verticalInTheRange = true;
          verticalLines.push({
            x: objectLeft - objectWidth / 2,
            y1: objectTop < activeObjectTop ? objectTop - objectHeight / 2 - aligningLineOffset : objectTop + objectHeight / 2 + aligningLineOffset,
            y2: activeObjectTop > objectTop ? activeObjectTop + activeObjectHeight / 2 + aligningLineOffset : activeObjectTop - activeObjectHeight / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(objectLeft - objectWidth / 2 + activeObjectWidth / 2, activeObjectTop), 'center', 'center');
        } // snap by the right edge


        if (isInRange(objectLeft + objectWidth / 2, activeObjectLeft + activeObjectWidth / 2)) {
          verticalInTheRange = true;
          verticalLines.push({
            x: objectLeft + objectWidth / 2,
            y1: objectTop < activeObjectTop ? objectTop - objectHeight / 2 - aligningLineOffset : objectTop + objectHeight / 2 + aligningLineOffset,
            y2: activeObjectTop > objectTop ? activeObjectTop + activeObjectHeight / 2 + aligningLineOffset : activeObjectTop - activeObjectHeight / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(objectLeft + objectWidth / 2 - activeObjectWidth / 2, activeObjectTop), 'center', 'center');
        } // snap by the vertical center line


        if (isInRange(objectTop, activeObjectTop)) {
          horizontalInTheRange = true;
          horizontalLines.push({
            y: objectTop,
            x1: objectLeft < activeObjectLeft ? objectLeft - objectWidth / 2 - aligningLineOffset : objectLeft + objectWidth / 2 + aligningLineOffset,
            x2: activeObjectLeft > objectLeft ? activeObjectLeft + activeObjectWidth / 2 + aligningLineOffset : activeObjectLeft - activeObjectWidth / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(activeObjectLeft, objectTop), 'center', 'center');
        } // snap by the top edge


        if (isInRange(objectTop - objectHeight / 2, activeObjectTop - activeObjectHeight / 2)) {
          horizontalInTheRange = true;
          horizontalLines.push({
            y: objectTop - objectHeight / 2,
            x1: objectLeft < activeObjectLeft ? objectLeft - objectWidth / 2 - aligningLineOffset : objectLeft + objectWidth / 2 + aligningLineOffset,
            x2: activeObjectLeft > objectLeft ? activeObjectLeft + activeObjectWidth / 2 + aligningLineOffset : activeObjectLeft - activeObjectWidth / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(activeObjectLeft, objectTop - objectHeight / 2 + activeObjectHeight / 2), 'center', 'center');
        } // snap by the bottom edge


        if (isInRange(objectTop + objectHeight / 2, activeObjectTop + activeObjectHeight / 2)) {
          horizontalInTheRange = true;
          horizontalLines.push({
            y: objectTop + objectHeight / 2,
            x1: objectLeft < activeObjectLeft ? objectLeft - objectWidth / 2 - aligningLineOffset : objectLeft + objectWidth / 2 + aligningLineOffset,
            x2: activeObjectLeft > objectLeft ? activeObjectLeft + activeObjectWidth / 2 + aligningLineOffset : activeObjectLeft - activeObjectWidth / 2 - aligningLineOffset
          });
          activeObject.setPositionByOrigin(new fabric.fabric.Point(activeObjectLeft, objectTop + objectHeight / 2 - activeObjectHeight / 2), 'center', 'center');
        }
      }

      if (!horizontalInTheRange) {
        horizontalLines.length = 0;
      }

      if (!verticalInTheRange) {
        verticalLines.length = 0;
      }
    });
    canvas.on('before:render', function () {
      canvas.clearContext(canvas.contextTop);
    });
    canvas.on('after:render', function () {
      for (var i = verticalLines.length; i--;) {
        drawVerticalLine(verticalLines[i]);
      }

      for (var _i = horizontalLines.length; _i--;) {
        drawHorizontalLine(horizontalLines[_i]);
      }

      verticalLines.length = horizontalLines.length = 0;
    });
    canvas.on('mouse:up', function () {
      verticalLines.length = horizontalLines.length = 0;
      canvas.renderAll();
    });
  };

  return GuidelinesHandler;
}(BaseHandler);

var BackgroundHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(BackgroundHandler, _BaseHandler);

  function BackgroundHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.getBackground = function () {
      return _this.canvas.getObjects().find(function (object) {
        return object.type === ObjectType.BACKGROUND;
      });
    };

    _this.setSize = function (options) {
      var background = _this.getBackground();

      if (background) {
        var width = options.width,
            height = options.height;
        background.set('width', width);
        background.set('height', height);
        background.center();
      }
    };

    _this.setBackgroundColor = function (color) {
      var background = _this.getBackground();

      if (background) {
        background.set('fill', color);

        _this.canvas.requestRenderAll();

        _this.handlers.historyHandler.save('background:fill');
      }
    };

    _this.setGradient = function (_ref) {
      var angle = _ref.angle,
          colors = _ref.colors;

      var background = _this.getBackground();

      if (background) {
        _this.setObjectGradient(background, angle, colors);

        _this.canvas.requestRenderAll();

        _this.handlers.historyHandler.save('background:gradient');
      }
    };

    _this.setHoverCursor = function (cursor) {
      var background = _this.getBackground();

      if (background) {
        background.set('hoverCursor', cursor);
      }
    };

    _this.setObjectGradient = function (object, angle, colors) {
      var odx = object.width >> 1;
      var ody = object.height >> 1;
      var startPoint = angleToPoint(angle, object.width, object.height);
      var endPoint = {
        x: object.width - startPoint.x,
        y: object.height - startPoint.y
      };
      object.set('fill', new fabric.fabric.Gradient({
        type: 'linear',
        coords: {
          x1: startPoint.x - odx,
          y1: startPoint.y - ody,
          x2: endPoint.x - odx,
          y2: endPoint.y - ody
        },
        colorStops: [{
          offset: 0,
          color: colors[0]
        }, {
          offset: 1,
          color: colors[1]
        }]
      }));
    };

    return _this;
  }

  return BackgroundHandler;
}(BaseHandler);

var Animations$1;

(function (Animations) {
  Animations["NONE"] = "NONE";
  Animations["STOMP"] = "STOMP";
  Animations["TUMBLE"] = "TUMBLE";
  Animations["RISE"] = "RISE";
  Animations["PAN"] = "PAN";
  Animations["FADE"] = "FADE";
  Animations["BREATHE"] = "BREATHE";
})(Animations$1 || (Animations$1 = {}));

var AnimationHandler = /*#__PURE__*/function (_BaseHandler) {
  _inheritsLoose(AnimationHandler, _BaseHandler);

  function AnimationHandler(props) {
    var _this;

    _this = _BaseHandler.call(this, props) || this;

    _this.animate = function (animation) {
      var _animations;

      var activeObject = _this.canvas.getActiveObject();

      var animations = (_animations = {}, _animations[Animations$1.NONE] = {}, _animations[Animations$1.TUMBLE] = {
        duration: 0.5,
        left: 0 - activeObject.width,
        angle: 45,
        ease: gsap.Linear.easeInOut
      }, _animations[Animations$1.STOMP] = {
        duration: 1,
        ease: 'slow(0.7, 0.7, false)',
        scaleX: 1.5 * activeObject.scaleX,
        scaleY: 1.5 * activeObject.scaleY
      }, _animations[Animations$1.RISE] = {
        duration: 0.5,
        top: activeObject.top + activeObject.height * 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations[Animations$1.PAN] = {
        duration: 0.5,
        left: activeObject.left - activeObject.width * activeObject.scaleX / 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations[Animations$1.FADE] = {
        duration: 1,
        opacity: 0,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations[Animations$1.BREATHE] = {
        duration: 1,
        scaleX: activeObject.scaleX + activeObject.scaleX / 2,
        scaleY: activeObject.scaleY + activeObject.scaleY / 2,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations);

      if (activeObject) {
        activeObject.set('animation', animation);

        _this.anim.from(activeObject, _extends({}, animations[animation], {
          onUpdate: function onUpdate() {
            _this.canvas.requestRenderAll();
          },
          onComplete: function onComplete() {
            activeObject.setCoords();
          }
        }));
      }
    };

    _this.setTemplateAnimations = function () {
      _this.anim = gsap__default.timeline({
        paused: true
      }); // this.anim.clear()

      var objects = _this.canvas.getObjects();

      objects.forEach(function (object) {
        if (object.animation) {
          // @ts-ignore
          _this.animateObject(object, object.animation);
        }
      });
    };

    _this.animateObject = function (object, animation) {
      var _animations2;

      var animations = (_animations2 = {}, _animations2[Animations$1.NONE] = {}, _animations2[Animations$1.TUMBLE] = {
        duration: 0.5,
        left: 0 - object.width,
        angle: 45,
        ease: gsap.Linear.easeInOut
      }, _animations2[Animations$1.STOMP] = {
        duration: 1,
        ease: 'slow(0.7, 0.7, false)',
        scaleX: 1.5 * object.scaleX,
        scaleY: 1.5 * object.scaleY
      }, _animations2[Animations$1.RISE] = {
        duration: 0.5,
        top: object.top + object.height * 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations2[Animations$1.PAN] = {
        duration: 0.5,
        left: object.left - object.width * object.scaleX / 2,
        opacity: 0,
        ease: 'pexpo.out'
      }, _animations2[Animations$1.FADE] = {
        duration: 1,
        opacity: 0,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations2[Animations$1.BREATHE] = {
        duration: 1,
        scaleX: object.scaleX + object.scaleX / 2,
        scaleY: object.scaleY + object.scaleY / 2,
        ease: 'slow(0.7, 0.7, false)'
      }, _animations2);

      if (object && animations[animation]) {
        _this.anim.from(object, _extends({}, animations[animation], {
          onUpdate: function onUpdate() {
            _this.canvas.requestRenderAll();
          },
          onComplete: function onComplete() {
            object.setCoords();
          }
        }), 0);
      }

      _this.anim.play();
    };

    _this.anim = gsap__default.timeline();
    return _this;
  }

  return AnimationHandler;
}(BaseHandler);

var Handlers = function Handlers(props) {
  this.destroy = function () {};

  this.propertiesToInclude = PROPERTIES_TO_INCLUDE;
  this.canvas = props.canvas;
  var handlerOptions = {
    handlers: this,
    canvas: props.canvas,
    context: props.context,
    config: props.config,
    editor: props.editor
  };
  this.canvasHandler = new CanvasHandler(handlerOptions);
  this.frameHandler = new FrameHandler(handlerOptions);
  this.objectsHandler = new ObjectHandler(handlerOptions);
  this.historyHandler = new HistoryHandler(handlerOptions);
  this.zoomHandler = new ZoomHandler(handlerOptions);
  this.eventsHandler = new EventsHandler(handlerOptions);
  this.personalizationHandler = new PersonalizationHandler(handlerOptions);
  this.templateHandler = new TemplateHandler(handlerOptions);
  this.scrollbarHandler = new ScrollbarHandler(handlerOptions);
  this.designHandler = new DesignHandler(handlerOptions);
  this.gifHandler = new GifHandler(handlerOptions);
  this.guidelinesHandler = new GuidelinesHandler(handlerOptions);
  this.backgroundHandler = new BackgroundHandler(handlerOptions);
  this.animationHandler = new AnimationHandler(handlerOptions);
};

var EventManager = /*#__PURE__*/function () {
  function EventManager() {
    this.all = new Map(); //   public all() {}
  }
  /**
   * Register an event handler for the given type.
   * @param {string|symbol} type Type of event to listen for, or `'*'` for all events
   * @param {Function} handler Function to call in response to given event
   * @memberOf EventManager
   */


  var _proto = EventManager.prototype;

  _proto.on = function on(type, handler) {
    var handlers = this.all.get(type);

    if (handlers) {
      handlers.push(handler);
    } else {
      this.all.set(type, [handler]);
    }
  }
  /**
   * Remove an event handler for the given type.
   * If `handler` is omitted, all handlers of the given type are removed.
   * @param {string|symbol} type Type of event to unregister `handler` from, or `'*'`
   * @param {Function} [handler] Handler function to remove
   * @memberOf EventManager
   */
  ;

  _proto.off = function off(type, handler) {
    var handlers = this.all.get(type);

    if (handlers) {
      if (handler) {
        handlers.splice(handlers.indexOf(handler) >>> 0, 1);
      } else {
        this.all.set(type, []);
      }
    }
  }
  /**
   * Invoke all handlers for the given type.
   * If present, `'*'` handlers are invoked after type-matched handlers.
   *
   * Note: Manually firing '*' handlers is not supported.
   *
   * @param {string|symbol} type The event type to invoke
   * @param {Any} [evt] Any value (object is recommended and powerful), passed to each handler
   * @memberOf EventManager
   */
  ;

  _proto.emit = function emit(type, evt) {
    var handlers = this.all.get(type);

    if (handlers) {
      handlers.slice().map(function (handler) {
        handler(evt);
      });
    }

    handlers = this.all.get('*');

    if (handlers) {
      handlers.slice().map(function (handler) {
        handler(type, evt);
      });
    }
  };

  return EventManager;
}();

var ZoomController = function ZoomController(handler) {
  var _this = this;

  this.zoomIn = function () {
    _this.handler.zoomIn();
  };

  this.zoomOut = function () {
    _this.handler.zoomOut();
  };

  this.zoomToOne = function () {
    _this.handler.zoomToOne();
  };

  this.zoomToFit = function () {
    _this.handler.zoomToFit();
  };

  this.zoomToRatio = function (zoomRatio) {
    _this.handler.zoomToRatio(zoomRatio);
  };

  this.handler = handler;
};

var BackgroundController = function BackgroundController(handler) {
  var _this = this;

  this.setBackgroundColor = function (color) {
    _this.handler.setBackgroundColor(color);
  };

  this.setGradient = function (_ref) {
    var angle = _ref.angle,
        colors = _ref.colors;

    _this.handler.setGradient({
      angle: angle,
      colors: colors
    });
  };

  this.handler = handler;
};

var CanvasController = /*#__PURE__*/function () {
  function CanvasController(handler) {
    this.handler = handler;
  }

  var _proto = CanvasController.prototype;

  _proto.resize = function resize(nextWidth, nextHeight) {
    this.handler.resize(nextWidth, nextHeight);
  };

  return CanvasController;
}();

var FrameController = /*#__PURE__*/function () {
  function FrameController(handler) {
    this.handler = handler;
  }

  var _proto = FrameController.prototype;

  _proto.update = function update(options) {
    this.handler.update(options);
  };

  _proto.setSize = function setSize(options) {
    this.handler.setSize(options);
  };

  return FrameController;
}();

var Editor = /*#__PURE__*/function (_EventManager) {
  _inheritsLoose(Editor, _EventManager);

  function Editor(props) {
    var _this;

    _this = _EventManager.call(this) || this; // BASIC FUNCTIONS
    // Add objects to editor

    _this.add = function (options) {
      _this.handlers.objectsHandler.add(options);
    }; // Update selected object properties


    _this.update = function (options) {
      _this.handlers.objectsHandler.update(options);
    };

    _this.copy = function () {
      _this.handlers.objectsHandler.copy();
    };

    _this.copyStyle = function () {
      _this.handlers.objectsHandler.copyStyle();
    };

    _this.cut = function () {
      _this.handlers.objectsHandler.cut();
    };

    _this.paste = function () {
      _this.handlers.objectsHandler.paste();
    };

    _this.clone = function () {
      _this.handlers.objectsHandler.clone();
    };

    _this["delete"] = function () {
      _this.handlers.objectsHandler.remove();
    };

    _this.clear = function () {
      _this.handlers.objectsHandler.clear();
    };

    _this.deselect = function () {
      _this.handlers.objectsHandler.deselect();
    }; // QUERY


    _this.findByName = function (name) {
      return _this.handlers.objectsHandler.findByName(name);
    };

    _this.removeByName = function (name) {
      _this.handlers.objectsHandler.removeByName(name);
    };

    _this.findById = function (id) {
      return _this.handlers.objectsHandler.findById(id);
    };

    _this.removeById = function (id) {
      _this.handlers.objectsHandler.removeById(id);
    }; // HISTORY


    _this.undo = function () {
      _this.handlers.historyHandler.undo();
    };

    _this.redo = function () {
      _this.handlers.historyHandler.redo();
    }; // ZOOM


    _this.zoomIn = function () {
      _this.handlers.zoomHandler.zoomIn();
    };

    _this.zoomOut = function () {
      _this.handlers.zoomHandler.zoomOut();
    };

    _this.zoomToOne = function () {
      _this.handlers.zoomHandler.zoomToOne();
    };

    _this.zoomToFit = function () {
      _this.handlers.zoomHandler.zoomToFit();
    };

    _this.zoomToRatio = function (zoomRatio) {
      _this.handlers.zoomHandler.zoomToRatio(zoomRatio);
    }; // ALIGMENT


    _this.alignTop = function () {
      _this.handlers.objectsHandler.alignTop();
    };

    _this.alignMiddle = function () {
      _this.handlers.objectsHandler.alignMiddle();
    };

    _this.alignBottom = function () {
      _this.handlers.objectsHandler.alignBottom();
    };

    _this.alignLeft = function () {
      _this.handlers.objectsHandler.alignLeft();
    };

    _this.alignCenter = function () {
      _this.handlers.objectsHandler.alignCenter();
    };

    _this.alignRight = function () {
      _this.handlers.objectsHandler.alignRight();
    }; //LAYERS


    _this.bringForward = function () {
      _this.handlers.objectsHandler.bringForward();
    };

    _this.bringToFront = function () {
      _this.handlers.objectsHandler.bringToFront();
    };

    _this.sendBackwards = function () {
      _this.handlers.objectsHandler.sendBackwards();
    };

    _this.sendToBack = function () {
      _this.handlers.objectsHandler.sendToBack();
    }; // GROUP


    _this.group = function () {
      _this.handlers.objectsHandler.group();
    };

    _this.ungroup = function () {
      _this.handlers.objectsHandler.ungroup();
    }; // LOCK - UNLOCK


    _this.lock = function () {
      _this.handlers.objectsHandler.lock();
    };

    _this.unlock = function () {
      _this.handlers.objectsHandler.unlock();
    }; // GRADIENT


    _this.setGradient = function (options) {
      _this.handlers.objectsHandler.setGradient(options);
    }; // SHADOW


    _this.setShadow = function (options) {
      _this.handlers.objectsHandler.setShadow(options);
    }; // DESIGN


    _this.exportToJSON = function () {
      return _this.handlers.templateHandler.exportToJSON();
    };

    _this.importFromJSON = function (data) {
      _this.handlers.templateHandler.importFromJSON(data);
    };

    _this.toSVG = function () {};

    _this.toPNG = function (options) {
      return _this.handlers.designHandler.toDataURL(options);
    };

    _this.toGif = function (options) {
      return _this.handlers.gifHandler.toGif(options);
    }; // CONTEXT MENU


    _this.cancelContextMenu = function () {
      _this.context.setContextMenuRequest(null);
    };

    _this.destroy = function () {
      _this.handlers.destroy();
    }; // ANIMATIONS


    _this.animate = function (name) {
      _this.handlers.animationHandler.animate(name);
    };

    _this.context = props.context;
    _this.handlers = new Handlers(_extends({}, props, {
      editor: _assertThisInitialized(_this)
    }));
    _this.zoom = new ZoomController(_this.handlers.zoomHandler);
    _this.background = new BackgroundController(_this.handlers.backgroundHandler);
    _this.canvas = new CanvasController(_this.handlers.canvasHandler);
    _this.frame = new FrameController(_this.handlers.frameHandler);
    return _this;
  }

  return Editor;
}(EventManager);

var FrameObject = /*#__PURE__*/function (_fabric$Rect) {
  _inheritsLoose(FrameObject, _fabric$Rect);

  function FrameObject() {
    return _fabric$Rect.apply(this, arguments) || this;
  }

  var _proto = FrameObject.prototype;

  _proto.initialize = function initialize(options) {
    _fabric$Rect.prototype.initialize.call(this, _extends({}, options, {
      selectable: false,
      hasControls: false,
      lockMovementY: true,
      lockMovementX: true,
      strokeWidth: 0,
      padding: 0,
      evented: false
    }));

    return this;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Rect.prototype.toObject.call(this, propertiesToInclude);
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Rect.prototype.toObject.call(this, propertiesToInclude);
  };

  FrameObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.Frame(options));
  };

  return FrameObject;
}(fabric.fabric.Rect);
FrameObject.type = 'Frame';
fabric.fabric.Frame = /*#__PURE__*/fabric.fabric.util.createClass(FrameObject, {
  type: FrameObject.type
});
fabric.fabric.Frame.fromObject = FrameObject.fromObject;

var _excluded$1 = ["text"];
var StaticTextObject = /*#__PURE__*/function (_fabric$Textbox) {
  _inheritsLoose(StaticTextObject, _fabric$Textbox);

  function StaticTextObject() {
    return _fabric$Textbox.apply(this, arguments) || this;
  }

  var _proto = StaticTextObject.prototype;

  _proto.initialize = function initialize(options) {
    var text = options.text,
        textOptions = _objectWithoutPropertiesLoose(options, _excluded$1); //@ts-ignore


    _fabric$Textbox.prototype.initialize.call(this, text, textOptions);

    return this;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Textbox.prototype.toObject.call(this, propertiesToInclude);
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Textbox.prototype.toObject.call(this, propertiesToInclude);
  };

  StaticTextObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.StaticText(options));
  };

  return StaticTextObject;
}(fabric.fabric.Textbox);
StaticTextObject.type = 'StaticText';
fabric.fabric.StaticText = /*#__PURE__*/fabric.fabric.util.createClass(StaticTextObject, {
  type: StaticTextObject.type
});
fabric.fabric.StaticText.fromObject = StaticTextObject.fromObject;

function drawTopRightIcon(ctx, left, top, __styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(0, 0);
  ctx.lineTo(0.5, 12);
  ctx.moveTo(0, 0);
  ctx.lineTo(-12, 0);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
function drawTopLeftIcon(ctx, left, top, __styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(0, 0);
  ctx.lineTo(0.5, 12);
  ctx.moveTo(0, 0);
  ctx.lineTo(12, 0);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
function drawBottomLeftIcon(ctx, left, top, __styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(0, 0);
  ctx.lineTo(0, -12);
  ctx.moveTo(0, 0);
  ctx.lineTo(12, 0);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
function drawBottomRightIcon(ctx, left, top, __styleOverride, fabricObject) {
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(0, 0);
  ctx.lineTo(0, -12);
  ctx.moveTo(0, 0);
  ctx.lineTo(-12, 0);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
function drawVerticalLineIcon$1(ctx, left, top, __styleOverride, fabricObject) {
  var size = 24;
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(-0.5, -size / 4);
  ctx.lineTo(-0.5, -size / 4 + size / 2);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
function drawHorizontalLineIcon$1(ctx, left, top, __styleOverride, fabricObject) {
  var size = 24;
  ctx.save();
  ctx.translate(left, top);
  ctx.rotate(fabric.fabric.util.degreesToRadians(fabricObject.angle));
  ctx.beginPath();
  ctx.lineCap = 'round';
  ctx.lineWidth = 3;
  ctx.shadowBlur = 2;
  ctx.shadowColor = 'black';
  ctx.moveTo(-size / 4, -0.5);
  ctx.lineTo(-size / 4 + size / 2, -0.5);
  ctx.strokeStyle = '#ffffff';
  ctx.stroke();
  ctx.restore();
}
var controlPositionIcons = {
  tl: drawTopLeftIcon,
  t: drawHorizontalLineIcon$1,
  tr: drawTopRightIcon,
  r: drawVerticalLineIcon$1,
  br: drawBottomRightIcon,
  b: drawHorizontalLineIcon$1,
  bl: drawBottomLeftIcon,
  l: drawVerticalLineIcon$1
};

var ControlPositions;

(function (ControlPositions) {
  ControlPositions["TOP_LEFT"] = "tl";
  ControlPositions["TOP"] = "t";
  ControlPositions["TOP_RIGHT"] = "tr";
  ControlPositions["RIGHT"] = "r";
  ControlPositions["BOTTOM_RIGHT"] = "br";
  ControlPositions["BOTTOM"] = "b";
  ControlPositions["BOTTOM_LEFT"] = "bl";
  ControlPositions["LEFT"] = "l";
})(ControlPositions || (ControlPositions = {}));

var StaticImageObject = /*#__PURE__*/function (_fabric$Image) {
  _inheritsLoose(StaticImageObject, _fabric$Image);

  function StaticImageObject() {
    var _this;

    _this = _fabric$Image.apply(this, arguments) || this;
    _this._editingMode = false;
    _this.__editingImage = null;
    _this.cornerLengthEditing = 5;
    /**
     * Color of the corner stroke in editing mode.
     */

    _this.cornerStrokeColorEditing = 'black';
    /**
     * Size of the corner stroke in editing mode.
     */

    _this.cornerSizeEditing = 2;
    return _this;
  }

  var _proto = StaticImageObject.prototype;

  _proto.registerEditingEvents = function registerEditingEvents() {
    var _this2 = this;

    this.on('mousedblclick', function () {
      if (!_this2._editingMode) {
        return _this2.enterEditingMode();
      } else {
        _this2.exitEditingMode();
      }
    });
    this.on('deselected', function () {
      _this2.exitEditingMode();
    });
  };

  _proto.enterEditingMode = function enterEditingMode() {
    var _this3 = this;

    if (this.selectable && this.canvas) {
      this._editingMode = true;
      this.clone(function (image) {
        var _this3$canvas;

        image.clipPath = null;
        var element = image.getElement();
        var _image$top = image.top,
            top = _image$top === void 0 ? 0 : _image$top,
            _image$left = image.left,
            left = _image$left === void 0 ? 0 : _image$left,
            _image$cropX = image.cropX,
            cropX = _image$cropX === void 0 ? 0 : _image$cropX,
            _image$cropY = image.cropY,
            cropY = _image$cropY === void 0 ? 0 : _image$cropY,
            _image$scaleX = image.scaleX,
            scaleX = _image$scaleX === void 0 ? 1 : _image$scaleX,
            _image$scaleY = image.scaleY,
            scaleY = _image$scaleY === void 0 ? 1 : _image$scaleY;
        image.set({
          top: top - cropY * scaleY,
          left: left - cropX * scaleX,
          height: element.height,
          width: element.width,
          cropX: 0,
          cropY: 0,
          opacity: 0.6,
          selectable: true,
          evented: false,
          excludeFromExport: true
        });
        _this3.__editingImage = image;

        _this3.canvas.add(_this3.__editingImage); // this.on('moving', (this.__editingOnMoving = this.__editingOnMoving.bind(this)))


        _this3.controls = _this3.__editingControls(); // this.fire('enter:editing', { target: this })

        (_this3$canvas = _this3.canvas) == null ? void 0 : _this3$canvas.requestRenderAll();
      });
    }
  };

  _proto.exitEditingMode = function exitEditingMode() {
    if (this.selectable && this.canvas) {
      var _this$canvas;

      this._editingMode = false;

      if (this.__editingImage) {
        this.canvas.remove(this.__editingImage);
        this.__editingImage = null;
      }

      this.off('moving', this.__editingOnMoving);
      this.controls = fabric.fabric.Object.prototype.controls;
      this.fire('exit:editing', {
        target: this
      });
      (_this$canvas = this.canvas) == null ? void 0 : _this$canvas.requestRenderAll();
    }
  } // @ts-ignore
  ;

  _proto.__editingControls = function __editingControls() {
    var controls = Object.values(ControlPositions);
    return controls.map(this.__createEditingControl.bind(this));
  };

  _proto.__createEditingControl = function __createEditingControl(position) {
    var cursor = position.replace('t', 's').replace('l', 'e').replace('b', 'n').replace('r', 'w');
    return new fabric.fabric.Control({
      cursorStyle: cursor + '-resize',
      actionName: "edit_" + this.type,
      render: controlPositionIcons[position],
      positionHandler: this.__editingControlPositionHandler.bind(this, position),
      actionHandler: this.__editingActionHandlerWrapper(position)
    });
  };

  _proto.__editingActionHandlerWrapper = function __editingActionHandlerWrapper(position) {
    var _this4 = this;

    return function (_event, _transform, x, y) {
      _this4.__editingSetCrop(position, x, y, true);

      return true;
    };
  } // @ts-ignore
  ;

  _proto.__editingOnMoving = function __editingOnMoving(event) {
    if (this._editingMode && event.pointer) {
      this.__editingSetCrop(ControlPositions.TOP_LEFT, this.left, this.top);
    }
  };

  _proto.__editingSetCrop = function __editingSetCrop(position, x, y, resize) {
    if (resize === void 0) {
      resize = false;
    }

    if (this.__editingImage) {
      var _this$__editingImage = this.__editingImage,
          _this$__editingImage$ = _this$__editingImage.top,
          top = _this$__editingImage$ === void 0 ? 0 : _this$__editingImage$,
          _this$__editingImage$2 = _this$__editingImage.left,
          left = _this$__editingImage$2 === void 0 ? 0 : _this$__editingImage$2,
          _this$__editingImage$3 = _this$__editingImage.width,
          width = _this$__editingImage$3 === void 0 ? 0 : _this$__editingImage$3,
          _this$__editingImage$4 = _this$__editingImage.height,
          height = _this$__editingImage$4 === void 0 ? 0 : _this$__editingImage$4,
          _this$__editingImage$5 = _this$__editingImage.scaleX,
          scaleX = _this$__editingImage$5 === void 0 ? 1 : _this$__editingImage$5,
          _this$__editingImage$6 = _this$__editingImage.scaleY,
          scaleY = _this$__editingImage$6 === void 0 ? 1 : _this$__editingImage$6;

      if (position.includes('t')) {
        var maxTop = top + height * scaleY - (resize ? 0 : this.getScaledHeight());
        var minTop = Math.min(y, maxTop, this.top + this.getScaledHeight());
        this.top = Math.max(minTop, top);
        var cropY = Math.min((Math.min(Math.max(y, top), this.top) - top) / scaleY, height);

        if (resize) {
          this.height = Math.max(0, Math.min(this.height + (this.cropY - cropY), height));
        }

        this.cropY = cropY;
      } else if (position.includes('b') && resize) {
        var minHeight = Math.min((y - top) / scaleY - this.cropY, height - this.cropY);
        this.height = Math.max(0, minHeight);
      }

      if (position.includes('l')) {
        var maxLeft = left + width * scaleX - (resize ? 0 : this.getScaledWidth());
        var minLeft = Math.min(x, maxLeft, this.left + this.getScaledWidth());
        this.left = Math.max(minLeft, left);
        var cropX = Math.min((Math.min(Math.max(x, left), this.left) - left) / scaleX, width);

        if (resize) {
          this.width = Math.max(0, Math.min(this.width + (this.cropX - cropX), width));
        }

        this.cropX = cropX;
      } else if (position.includes('r') && resize) {
        var minWidth = Math.min((x - left) / scaleX - this.cropX, width - this.cropX);
        this.width = Math.max(0, minWidth);
      }
    }
  };

  _proto.__editingControlPositionHandler = function __editingControlPositionHandler(position) {
    var xMultiplier = position.includes('l') ? -1 : position.length > 1 || position === 'r' ? 1 : 0;
    var yMultiplier = position.includes('t') ? -1 : position.length > 1 || position === 'b' ? 1 : 0;
    var x = this.width / 2 * xMultiplier;
    var y = this.height / 2 * yMultiplier;
    return fabric.fabric.util.transformPoint(new fabric.fabric.Point(x, y), fabric.fabric.util.multiplyTransformMatrices(this.canvas.viewportTransform, this.calcTransformMatrix()));
  };

  _proto.__renderEditingControl = function __renderEditingControl(position, ctx, left, top) {
    ctx.save();
    ctx.strokeStyle = this.cornerStrokeColorEditing;
    ctx.lineWidth = this.cornerSizeEditing;
    ctx.translate(left, top);

    if (this.angle) {
      ctx.rotate(fabric.fabric.util.degreesToRadians(this.angle));
    }

    ctx.beginPath();
    var x = position.includes('l') ? -ctx.lineWidth : position.includes('r') ? ctx.lineWidth : 0;
    var y = position.includes('t') ? -ctx.lineWidth : position.includes('b') ? ctx.lineWidth : 0;

    if (position === 'b' || position === 't') {
      ctx.moveTo(x - this.cornerLengthEditing / 2, y);
      ctx.lineTo(x + this.cornerLengthEditing, y);
    } else if (position === 'r' || position === 'l') {
      ctx.moveTo(x, y - this.cornerLengthEditing / 2);
      ctx.lineTo(x, y + this.cornerLengthEditing);
    } else {
      if (position.includes('b')) {
        ctx.moveTo(x, y - this.cornerLengthEditing);
      } else if (position.includes('t')) {
        ctx.moveTo(x, y + this.cornerLengthEditing);
      }

      ctx.lineTo(x, y);

      if (position.includes('r')) {
        ctx.lineTo(x - this.cornerLengthEditing, y);
      } else if (position.includes('l')) {
        ctx.lineTo(x + this.cornerLengthEditing, y);
      }
    }

    ctx.stroke();
    ctx.restore();
  } //@ts-ignore
  ;

  _proto.initialize = function initialize(element, options) {
    // @ts-ignore
    this.registerEditingEvents(); //@ts-ignore

    _fabric$Image.prototype.initialize.call(this, element, options);

    return this;
  };

  StaticImageObject.fromObject = function fromObject(options, callback) {
    fabric.fabric.util.loadImage(options.src, function (img) {
      // @ts-ignore
      return callback && callback(new fabric.fabric.StaticImage(img, options));
    }, null, // @ts-ignore
    {
      crossOrigin: 'anonymous'
    });
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Image.prototype.toObject.call(this, propertiesToInclude);
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Image.prototype.toObject.call(this, propertiesToInclude);
  };

  return StaticImageObject;
}(fabric.fabric.Image);
StaticImageObject.type = 'StaticImage';
fabric.fabric.StaticImage = /*#__PURE__*/fabric.fabric.util.createClass(StaticImageObject, {
  type: StaticImageObject.type
});
fabric.fabric.StaticImage.fromObject = StaticImageObject.fromObject;

var StaticVectorObject = /*#__PURE__*/function (_fabric$Group) {
  _inheritsLoose(StaticVectorObject, _fabric$Group);

  function StaticVectorObject() {
    return _fabric$Group.apply(this, arguments) || this;
  }

  var _proto = StaticVectorObject.prototype;

  //@ts-ignore
  _proto.initialize = function initialize(objects, options, others) {
    this.set('src', others.src);
    var object = fabric.fabric.util.groupSVGElements(objects, options); //@ts-ignore

    _fabric$Group.prototype.initialize.call(this, [object], others);

    return this;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    // @ts-ignore
    return _fabric$Group.prototype.toObject.call(this, propertiesToInclude, {
      src: this.src
    });
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    // @ts-ignore
    return _fabric$Group.prototype.toObject.call(this, propertiesToInclude, {
      src: this.src
    });
  };

  StaticVectorObject.fromObject = function fromObject(options, callback) {
    fabric.fabric.loadSVGFromURL(options.src, function (objects, opts) {
      return callback && callback(new fabric.fabric.StaticVector(objects, opts, _extends({}, options)));
    });
  };

  return StaticVectorObject;
}(fabric.fabric.Group);

StaticVectorObject.type = 'StaticVector';
fabric.fabric.StaticVector = /*#__PURE__*/fabric.fabric.util.createClass(StaticVectorObject, {
  type: StaticVectorObject.type
});
fabric.fabric.StaticVector.fromObject = StaticVectorObject.fromObject;

var _excluded$2 = ["path"];
var StaticPathObject = /*#__PURE__*/function (_fabric$Path) {
  _inheritsLoose(StaticPathObject, _fabric$Path);

  function StaticPathObject() {
    return _fabric$Path.apply(this, arguments) || this;
  }

  var _proto = StaticPathObject.prototype;

  _proto.initialize = function initialize(options) {
    var path = options.path,
        pathOptions = _objectWithoutPropertiesLoose(options, _excluded$2); //@ts-ignore


    _fabric$Path.prototype.initialize.call(this, path, pathOptions);

    return this;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Path.prototype.toObject.call(this, propertiesToInclude);
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Path.prototype.toObject.call(this, propertiesToInclude);
  };

  StaticPathObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.StaticPath(options));
  };

  return StaticPathObject;
}(fabric.fabric.Path);
StaticPathObject.type = 'StaticPath';
fabric.fabric.StaticPath = /*#__PURE__*/fabric.fabric.util.createClass(StaticPathObject, {
  type: StaticPathObject.type
});
fabric.fabric.StaticPath.fromObject = StaticPathObject.fromObject;

var _excluded$3 = ["text"];
var REGEX_VAR$1 = /*#__PURE__*/new RegExp(/\{\{[a-zA-Z0-9-_]+?\}\}/g);
var DynamicTextObject = /*#__PURE__*/function (_fabric$Textbox) {
  _inheritsLoose(DynamicTextObject, _fabric$Textbox);

  function DynamicTextObject() {
    var _this;

    _this = _fabric$Textbox.apply(this, arguments) || this;
    _this.initiated = false;
    _this.triggered = false;
    _this.keyValues = [];
    _this.keys = [];
    _this.keysBounds = [];
    _this.prevKey = '';
    _this.originalText = '';
    return _this;
  }

  var _proto = DynamicTextObject.prototype;

  _proto.updateKeyValues = function updateKeyValues() {
    var _this2 = this;

    var updatedKeyValues = [];
    var initialParams = this.getParamsFromKeys(this.text);
    initialParams.forEach(function (ip) {
      var existingParam = _this2.keyValues.find(function (kv) {
        return kv.key === ip.key;
      });

      if (existingParam) {
        updatedKeyValues = updatedKeyValues.concat(existingParam);
      } else {
        updatedKeyValues = updatedKeyValues.concat({
          key: ip.key,
          value: ip.key.substring(2, ip.key.length - 2)
        });
      }
    });
    this.keyValues = updatedKeyValues;
  };

  _proto.setValuesForKeys = function setValuesForKeys() {
    var _this3 = this;

    var keyParams = [];
    this.keyValues.forEach(function (keyValue) {
      var value = keyValue.value;
      var key = keyValue.key;
      var regex = new RegExp(key, 'g');

      var matches = _this3.text.matchAll(regex);

      var params = [];

      for (var _iterator = _createForOfIteratorHelperLoose(matches), _step; !(_step = _iterator()).done;) {
        var match = _step.value;
        var matchWord = match['0'];
        var startIndex = match['index'];
        params = params.concat({
          key: matchWord,
          startIndex: startIndex,
          endIndex: startIndex + matchWord.length,
          id: lodash.uniqueId(matchWord)
        });
      }

      params.forEach(function (param) {
        var id = lodash.uniqueId(param.key);

        var keyParam = _this3.replaceKeyWithValue(key, value, id);

        keyParams = keyParams.concat(keyParam);
      });
    });
    return keyParams;
  };

  _proto.getParamsFromKeys = function getParamsFromKeys(text) {
    var params = [];
    var matches = text.matchAll(REGEX_VAR$1);

    for (var _iterator2 = _createForOfIteratorHelperLoose(matches), _step2; !(_step2 = _iterator2()).done;) {
      var match = _step2.value;
      var matchWord = match['0'];
      var startIndex = match['index'];
      params = params.concat({
        key: matchWord,
        startIndex: startIndex,
        endIndex: startIndex + matchWord.length,
        id: lodash.uniqueId(matchWord)
      });
    }

    return params;
  };

  _proto.updateParams = function updateParams() {
    this.updateKeyValues();
    this.setValuesForKeys();
    this.setKeyBounds();
    this.updateKeys();
  };

  _proto.updateKeys = function updateKeys() {
    var _this4 = this;

    setTimeout(function () {
      var keys = [];

      var textLines = _this4.getUpdatedTextLines();

      textLines.forEach(function (textLine) {
        var params = _this4.getKeysFromTextStyles(textLine.lineStyles);

        params.forEach(function (param) {
          keys = keys.concat(param.key.substring(2, param.key.length - 2));
        });
      });
      _this4.keys = keys;
    }, 150);
  };

  _proto.replaceKeyWithValue = function replaceKeyWithValue(key, value, id) {
    var matchIndex = this.text.search(key);
    var styles = Array(value.length).fill({
      textBackgroundColor: '#d4d1cb',
      fill: '#29251f',
      key: key,
      id: id,
      value: value
    });

    if (matchIndex > -1) {
      this.insertChars(value, styles, matchIndex, matchIndex + key.length);
      return {
        id: id,
        key: key,
        value: value,
        startIndex: matchIndex,
        endIndex: matchIndex + value.length
      };
    }

    return false;
  };

  _proto.replaceValueWithKeyForText = function replaceValueWithKeyForText(textLine) {
    var params = this.getKeysFromTextStyles(textLine.lineStyles);
    var lineEnding = textLine.breakLine ? '\n' : '';
    var lineVariation = textLine.initialText === textLine.text ? '' : ' ';

    if (params.length === 0) {
      return lineVariation + textLine.initialText + lineEnding;
    } else {
      var pieces = [];
      var textArr = textLine.initialText.split('');
      params.forEach(function (param, index) {
        var currentParam = param;
        var prevParam = params[index - 1];
        var nextParam = params[index + 1];
        var diff = textLine.startIndex; // calculate initial section

        if (index === 0) {
          var initialSection = textArr.slice(0, param.startIndex - diff);

          if (initialSection.length > 0) {
            pieces = pieces.concat(initialSection.join(''));
          }
        } else {
          var _initialSection = textArr.slice(prevParam.endIndex - diff, currentParam.startIndex - diff);

          if (_initialSection.length > 0) {
            pieces = pieces.concat(_initialSection.join(''));
          }
        }

        pieces = pieces.concat(param.key.split(''));

        if (!nextParam) {
          var lastSection = textArr.slice(param.startIndex + param.value.length - diff);

          if (lastSection.length > 0) {
            pieces = pieces.concat(lastSection.join(''));
          }
        }
      });
      return lineVariation + pieces.join('') + lineEnding;
    }
  };

  _proto.getKeysFromTextStyles = function getKeysFromTextStyles(textSyles) {
    var charStyles = [];
    var params = [];
    Object.keys(textSyles).forEach(function (style) {
      if (textSyles[style].key && textSyles[style].value) {
        charStyles = charStyles.concat({
          index: parseInt(style),
          key: textSyles[style].key,
          value: textSyles[style].value,
          id: textSyles[style].id
        });
      }
    });
    var groupedCharStyles = lodash.groupBy(charStyles, 'id');
    Object.keys(groupedCharStyles).forEach(function (group) {
      var value = groupedCharStyles[group][0].value;
      var key = groupedCharStyles[group][0].key;
      var indexes = groupedCharStyles[group].map(function (g) {
        return g.index;
      }).sort(function (a, b) {
        return a - b;
      });
      var _ref = [indexes[0]],
          startIndex = _ref[0];
      var param = {
        key: key,
        value: value,
        startIndex: startIndex,
        endIndex: startIndex + value.length,
        id: group
      };
      params = params.concat(param);
    });
    return params;
  }
  /**
   * Update text lines normalizing text and adding styles by text line
   */
  ;

  _proto.getUpdatedTextLines = function getUpdatedTextLines() {
    var allText = this.text;
    var textLines = this.textLines;
    var updatedTextLines = [];
    var textStyleGroupIndex = 0;
    var startIndex = 0;
    var lineIndex = 0;
    textLines.forEach(function (textLine, index) {
      var currentTextLine = textLine;
      var isBreakLine = false;
      lineIndex = index;
      var prevUpdatedLine = updatedTextLines[index - 1];

      if (allText[0] === '\n') {
        allText = allText.substring(1);
        textStyleGroupIndex += 1;

        if (index) {
          prevUpdatedLine.breakLine = true;
        }
      } else {
        var textLineChange = index ? ' ' : '';
        currentTextLine = textLineChange + currentTextLine;
      }

      var initialPart = allText.substring(0, currentTextLine.length);
      var remainingPart = allText.substring(currentTextLine.length);

      if (index) {
        if (prevUpdatedLine.breakLine) {
          startIndex = 0;
        } else {
          startIndex = prevUpdatedLine.startIndex + prevUpdatedLine.text.length + 1;
        }
      }

      allText = remainingPart;
      updatedTextLines = updatedTextLines.concat({
        text: initialPart,
        breakLine: isBreakLine,
        textStyleGroupIndex: textStyleGroupIndex,
        startIndex: startIndex,
        lineIndex: lineIndex,
        initialText: textLine
      });
    });
    var textStyleGroups = this.styles;
    var updatedTextLinesWithStyles = updatedTextLines.map(function (updatedTextLine) {
      var textStyleGroup = textStyleGroups[updatedTextLine.textStyleGroupIndex];
      var indexes = Array(updatedTextLine.text.length).fill(0).map(function (_, i) {
        return (updatedTextLine.startIndex + i).toString();
      });
      var lineStyles = lodash.pick(textStyleGroup, indexes);
      return _extends({}, updatedTextLine, {
        lineStyles: lineStyles
      });
    });
    return updatedTextLinesWithStyles;
  };

  _proto.setKeyBounds = function setKeyBounds() {
    var _this5 = this;

    setTimeout(function () {
      var keysBounds = [];

      var textLines = _this5.getUpdatedTextLines();

      textLines.forEach(function (textLine) {
        var lineHeight = _this5.__lineHeights[parseInt(textLine.textStyleGroupIndex)];

        var params = _this5.getKeysFromTextStyles(textLine.lineStyles);

        var linekeyBounds = params.map(function (param) {
          var charBounds = _this5.__charBounds[textLine.lineIndex].map(function (cbs) {
            return _extends({}, cbs, {
              top: lineHeight * textLine.lineIndex
            });
          });

          var charBoundMin = charBounds[param.startIndex - textLine.startIndex];
          var charBoundMax = charBounds[param.endIndex - textLine.startIndex];

          if (!charBoundMin || !charBoundMax) {
            return {};
          }

          var lineWidth = _this5.__lineWidths[textLine.lineIndex];
          var width = _this5.width;
          var shift = 0;

          if (_this5.textAlign === 'center') {
            shift = (width - lineWidth) / 2;
          } else if (_this5.textAlign == 'right') {
            shift = width - lineWidth;
          }

          var charBound = _extends({}, charBoundMin, param, {
            shift: shift,
            left: shift + charBoundMin.left,
            top: charBoundMin.top,
            width: charBoundMax.width + charBoundMax.left - charBoundMin.left,
            height: charBoundMin.height
          });

          return charBound;
        });
        keysBounds = keysBounds.concat(linekeyBounds);
      });
      _this5.keysBounds = keysBounds;
    }, 250);
  }
  /**
   * Replace all values with keys
   */
  ;

  _proto.replaceValueWithKey = function replaceValueWithKey() {
    var _this6 = this;

    var textLines = this.getUpdatedTextLines();
    var updatedText = '';
    textLines.forEach(function (textLine) {
      var originalText = _this6.replaceValueWithKeyForText(textLine);

      updatedText += originalText;
    });
    this.insertChars(updatedText, null, 0, this.text.length);
  } // [IMPORTANT] ONLY one value at a time will be updated
  ;

  _proto.updateExistingValues = function updateExistingValues() {
    var _this7 = this;

    var textLines = this.getUpdatedTextLines();
    textLines.forEach(function (textLine) {
      var params = _this7.getKeysFromTextStyles(textLine.lineStyles);

      params.forEach(function (param) {
        var newParam = _this7.keyValues.find(function (kv) {
          return kv.key === param.key;
        });

        if (newParam.value !== param.value) {
          var key = newParam.key,
              value = newParam.value;
          var styles = Array(value.length).fill({
            textBackgroundColor: '#d4d1cb',
            fill: '#29251f',
            key: key,
            id: param.id,
            value: value
          });
          var textLinesLenght = textLines.map(function (tl) {
            return tl.initialText.length;
          }).slice(0, textLine.lineIndex).concat(0).reduce(function (a, b) {
            return a + b;
          });
          var a = textLinesLenght - textLine.startIndex + param.startIndex + textLine.lineIndex;
          var b = textLinesLenght - textLine.startIndex + param.endIndex + textLine.lineIndex;

          _this7.removeStyleFromTo(a, b);

          _this7.insertChars(value, styles, a, b);

          _this7.canvas.renderAll();
        }
      });
    });
    this.updateKeyValues();
  };

  _proto.removeEmptyText = function removeEmptyText() {
    if (!this.text) {
      this.canvas.remove(this);
    }
  };

  _proto.handleKeyDown = function handleKeyDown(e) {
    var key = e.key;

    if (this.triggered && this.isEditing) {
      var eventData = {
        object: this,
        isEditing: this.isEditing,
        visible: false,
        position: {
          left: 0,
          top: 0
        },
        key: null
      };
      this.canvas.fire('text:key:selected', eventData);
    }

    if (key === '{') {
      if (this.prevKey === '{') {
        var currentPosition = this.selectionStart;

        if (this.text[currentPosition - 1] === '{') {
          var _ref2;

          var canvasPosition = this.getCanvasBoundingClientRect();
          var cursorLocation = this.get2DCursorLocation();
          var zoom = this.canvas.getZoom();

          var charbounds = (_ref2 = []).concat.apply(_ref2, this.__charBounds);

          var charBound = charbounds[this.selectionStart];
          var scaleX = this.scaleX,
              scaleY = this.scaleY,
              width = this.width,
              height = this.height;

          var _this$getBoundingRect = this.getBoundingRect(false),
              left = _this$getBoundingRect.left,
              top = _this$getBoundingRect.top;

          var padLeft = (width * scaleX * zoom - width) / 2;
          var padTop = (height * scaleY * zoom - height) / 2;
          var _eventData = {
            object: this,
            isEditing: this.isEditing,
            visible: true,
            position: {
              left: canvasPosition.left + left + padLeft + charBound.left,
              top: canvasPosition.top + top + padTop + (cursorLocation.lineIndex + 1) * charBound.height * zoom
            },
            key: undefined
          };
          this.canvas.fire('text:key:selected', _eventData);
          this.triggered = true;
        }
      } else {
        this.prevKey = '{';
      }
    }
  };

  _proto.getCanvasBoundingClientRect = function getCanvasBoundingClientRect() {
    var canvasEl = document.getElementById('canvas');
    var position = {
      left: canvasEl == null ? void 0 : canvasEl.getBoundingClientRect().left,
      top: canvasEl == null ? void 0 : canvasEl.getBoundingClientRect().top
    };
    return position;
  };

  _proto.triggerKeysMenu = function triggerKeysMenu() {
    this.setCoords();
    var canvasPosition = this.getCanvasBoundingClientRect();
    var zoom = this.canvas.getZoom();
    var scaleX = this.scaleX,
        scaleY = this.scaleY,
        width = this.width,
        height = this.height;

    var _this$getBoundingRect2 = this.getBoundingRect(false),
        left = _this$getBoundingRect2.left,
        top = _this$getBoundingRect2.top;

    var padLeft = (width * scaleX * zoom - width) / 2;
    var padTop = (height * scaleY * zoom - height) / 2;
    var cursorLocation = this.get2DCursorLocation();
    var charBounds = this.__charBounds;
    var charBound = charBounds[cursorLocation.lineIndex][cursorLocation.charIndex];
    var eventData = {
      object: this,
      isEditing: this.isEditing,
      visible: true,
      position: {
        left: canvasPosition.left + left + padLeft + charBound.left,
        top: canvasPosition.top + top + padTop + (cursorLocation.lineIndex + 1) * charBound.height * zoom
      },
      key: undefined
    };
    this.canvas.fire('text:key:selected', eventData);
  };

  _proto.insertKey = function insertKey(value) {
    var _this$canvas;

    var initial = this.selectionStart;
    var end = this.selectionEnd;

    if (this.text[initial - 1] === '{') {
      this.insertChars(value, null, initial - 2, end);
      this.selectionStart = initial + value.length - 2;
    } else {
      this.insertChars(value, null, initial, end);
      this.selectionStart = initial + value.length;
    }

    this.exitEditing();
    (_this$canvas = this.canvas) == null ? void 0 : _this$canvas.renderAll();
    this.enterEditing();
  };

  _proto._set = function _set(key, value) {
    if (key === 'keyValues') {
      var keyValues = value ? value : [];

      if (keyValues.length > 0) {
        this.keyValues = keyValues;
        this.fire('text:keys:updated');
      }
    }

    return _fabric$Textbox.prototype._set.call(this, key, value);
  };

  _proto.initialize = function initialize(options) {
    var _this8 = this;

    var text = options.text,
        textOptions = _objectWithoutPropertiesLoose(options, _excluded$3);

    this.keys = [];
    this.keysBounds = [];
    this.keyValues = options.keyValues ? options.keyValues : [];
    this.triggered = false;
    var updatedKeyValues = [];
    var initialParams = this.getParamsFromKeys(text);
    initialParams.forEach(function (ip) {
      var existingParam = _this8.keyValues.find(function (kv) {
        return kv.key === ip.key;
      });

      if (existingParam) {
        updatedKeyValues = updatedKeyValues.concat(existingParam);
      } else {
        updatedKeyValues = updatedKeyValues.concat({
          key: ip.key,
          value: ip.key.substring(2, ip.key.length - 2)
        });
      }
    });
    this.keyValues = updatedKeyValues; // @ts-ignore

    _fabric$Textbox.prototype.initialize.call(this, text, _extends({}, textOptions, {
      backgroundColor: 'rgba(255,255,255,0)',
      keyValues: updatedKeyValues,
      editable: false
    }));

    this.on('modified', function () {
      _this8.removeEmptyText();
    });
    this.on('added', function () {
      _this8.canvas.on('mouse:move', function (e) {
        if (e.target === _this8) {
          var pointer = _this8.canvas.getPointer(e.e, false);

          var key = _this8.keysBounds.find(function (key) {
            if (pointer.x >= key.left + _this8.left && pointer.x <= _this8.left + key.left + key.width && pointer.y >= key.top + _this8.top && pointer.y <= _this8.top + key.top + key.height) {
              return true;
            } else {
              return false;
            }
          });

          if (key) {
            _this8.hoverCursor = 'pointer';
          } else {
            _this8.hoverCursor = 'move';
          }
        }
      });

      _this8.updateParams();
    });
    this.on('mousedblclick', function () {
      _this8.set('editable', true);

      _this8.enterEditing();
    });
    this.on('mouseup', function (e) {
      var pointer = _this8.canvas.getPointer(e.e, false);

      var key = _this8.keysBounds.find(function (key) {
        if (pointer.x >= key.left + _this8.left && pointer.x <= _this8.left + key.left + key.width && pointer.y >= key.top + _this8.top && pointer.y <= _this8.top + key.top + key.height) {
          return true;
        } else {
          return false;
        }
      });

      if (key && !_this8.isEditing) {
        var canvasPosition = _this8.getCanvasBoundingClientRect();

        _this8.setCoords();

        var zoom = _this8.canvas.getZoom();

        var scaleX = _this8.scaleX,
            scaleY = _this8.scaleY,
            width = _this8.width,
            height = _this8.height;

        var _this8$getBoundingRec = _this8.getBoundingRect(false),
            left = _this8$getBoundingRec.left,
            top = _this8$getBoundingRec.top;

        var padLeft = (width * scaleX * zoom - width) / 2;
        var padTop = (height * scaleY * zoom - height) / 2;
        var eventData = {
          object: _this8,
          isEditing: _this8.isEditing,
          visible: true,
          position: {
            left: canvasPosition.left + left + padLeft + key.width * zoom + key.left,
            top: canvasPosition.top + top + padTop + key.height * zoom + key.top
          },
          key: key
        };

        _this8.canvas.fire('text:key:selected', eventData);
      }
    });
    this.on('editing:entered', function () {
      var eventData = {
        object: _this8,
        isEditing: _this8.isEditing,
        visible: false,
        position: {
          left: 0,
          top: 0
        },
        key: null
      };

      _this8.canvas.fire('text:key:selected', eventData);

      if (!_this8.initiated) {
        _this8.replaceValueWithKey();

        _this8.initiated = true;

        _this8.exitEditing();
      }

      window.addEventListener('keydown', _this8.handleKeyDown.bind(_this8));
    });
    this.on('editing:exited', function () {
      if (_this8.initiated) {
        _this8.enterEditing();

        _this8.initiated = false;
      } else {
        _this8.updateParams();

        _this8.set('editable', false);
      }

      var eventData = {
        object: _this8,
        isEditing: _this8.isEditing,
        visible: false,
        position: {
          left: 0,
          top: 0
        },
        key: null
      };

      _this8.canvas.fire('text:key:selected', eventData);

      window.removeEventListener('keydown', _this8.handleKeyDown.bind(_this8));
    });
    this.on('text:keys:updated', function () {
      if (!_this8.isEditing) {
        _this8.updateExistingValues();
      }
    });
    return this;
  };

  _proto.getText = function getText() {
    var _this9 = this;

    var textLines = this.getUpdatedTextLines();
    var updatedText = '';
    textLines.forEach(function (textLine) {
      var originalText = _this9.replaceValueWithKeyForText(textLine);

      updatedText += originalText;
    });
    return updatedText;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    var originalText = this.getText();
    return fabric.fabric.util.object.extend(_fabric$Textbox.prototype.toObject.call(this, propertiesToInclude), {
      keys: this.keys,
      originalText: originalText,
      metadata: this.metadata
    });
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    var originalText = this.getText();
    return fabric.fabric.util.object.extend(_fabric$Textbox.prototype.toObject.call(this, propertiesToInclude), {
      keys: this.keys,
      originalText: originalText,
      metadata: this.metadata
    });
  };

  DynamicTextObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.DynamicText(options));
  };

  return DynamicTextObject;
}(fabric.fabric.Textbox);
DynamicTextObject.type = 'DynamicText';
fabric.fabric.DynamicText = /*#__PURE__*/fabric.fabric.util.createClass(DynamicTextObject, {
  type: DynamicTextObject.type
});
fabric.fabric.DynamicText.fromObject = DynamicTextObject.fromObject;

var imagePath = 'M50.1207 0H0.87931C0.646103 0 0.422447 0.117422 0.257544 0.326433C0.0926413 0.535444 0 0.818924 0 1.11451V49.8855C0 50.1811 0.0926413 50.4646 0.257544 50.6736C0.422447 50.8826 0.646103 51 0.87931 51H50.1207C50.3539 51 50.5776 50.8826 50.7425 50.6736C50.9074 50.4646 51 50.1811 51 49.8855V1.11451C51 0.818924 50.9074 0.535444 50.7425 0.326433C50.5776 0.117422 50.3539 0 50.1207 0ZM49.2414 48.771H1.75862V2.22902H49.2414V48.771Z M12.0386 23.74C13.1996 23.74 14.3345 23.3957 15.2998 22.7507C16.2651 22.1057 17.0175 21.189 17.4617 20.1164C17.906 19.0438 18.0223 17.8635 17.7958 16.7248C17.5693 15.5862 17.0102 14.5402 16.1893 13.7193C15.3684 12.8984 14.3224 12.3393 13.1838 12.1128C12.0451 11.8863 10.8648 12.0025 9.79222 12.4468C8.71962 12.8911 7.80285 13.6435 7.15785 14.6088C6.51285 15.5741 6.16858 16.709 6.16858 17.87C6.17122 19.426 6.79051 20.9175 7.89078 22.0178C8.99105 23.1181 10.4826 23.7374 12.0386 23.74ZM12.0386 14C12.804 14 13.5522 14.227 14.1886 14.6522C14.8251 15.0775 15.3211 15.6819 15.614 16.389C15.9069 17.0962 15.9835 17.8743 15.8342 18.625C15.6849 19.3757 15.3163 20.0653 14.7751 20.6065C14.2339 21.1477 13.5443 21.5163 12.7936 21.6656C12.0429 21.815 11.2647 21.7383 10.5576 21.4454C9.85044 21.1525 9.24603 20.6565 8.82079 20.0201C8.39555 19.3836 8.16858 18.6354 8.16858 17.87C8.16857 16.8427 8.57598 15.8573 9.30146 15.13C10.0269 14.4026 11.0113 13.9926 12.0386 13.99V14ZM2.93858 41.47C3.18165 41.4697 3.41627 41.3808 3.59858 41.22L19.9386 26.88L24.9386 31.53L30.6786 36.94C30.8722 37.1217 31.13 37.219 31.3954 37.2106C31.6608 37.2021 31.9119 37.0886 32.0936 36.895C32.2752 36.7014 32.3726 36.4435 32.3641 36.1782C32.3557 35.9128 32.2422 35.6617 32.0486 35.48L27.0486 30.74L36.0486 20.89L47.3086 31.37C47.5054 31.5296 47.7554 31.6085 48.0081 31.5908C48.2608 31.5732 48.4974 31.4603 48.6701 31.2749C48.8428 31.0895 48.9387 30.8455 48.9384 30.5921C48.9381 30.3388 48.8417 30.095 48.6686 29.91L36.6686 18.75C36.5741 18.6537 36.46 18.5788 36.3341 18.5305C36.2081 18.4822 36.0732 18.4616 35.9386 18.47C35.8065 18.4745 35.6767 18.505 35.5566 18.56C35.4364 18.6149 35.3283 18.6931 35.2386 18.79L25.5286 29.37L20.6686 24.79C20.4842 24.6214 20.2434 24.5278 19.9936 24.5278C19.7437 24.5278 19.5029 24.6214 19.3186 24.79L2.31858 39.74C2.17543 39.8733 2.07451 40.0456 2.0283 40.2357C1.9821 40.4257 1.99264 40.6251 2.05863 40.8093C2.12461 40.9934 2.24314 41.1541 2.39955 41.2715C2.55595 41.389 2.74336 41.458 2.93858 41.47Z'; //@ts-ignore

var DynamicImageObject = /*#__PURE__*/function (_fabric$Rect) {
  _inheritsLoose(DynamicImageObject, _fabric$Rect);

  function DynamicImageObject() {
    return _fabric$Rect.apply(this, arguments) || this;
  }

  var _proto = DynamicImageObject.prototype;

  _proto.getKeyScaling = function getKeyScaling() {
    var _this$getBoundingRect = this.getBoundingRect(),
        height = _this$getBoundingRect.height,
        width = _this$getBoundingRect.width;

    var scale = 1;

    if (height > 120 && width > 120) {
      scale = 1.5;
    }

    if (height < 80 && height > 70 || width < 80 && width > 70) {
      scale = 0.75;
    }

    if (height < 70 || width < 70) {
      scale = 0.55;
    }

    return scale;
  };

  _proto.getCanvasBoundingClientRect = function getCanvasBoundingClientRect() {
    var canvasEl = document.getElementById('canvas');
    var position = {
      left: canvasEl == null ? void 0 : canvasEl.getBoundingClientRect().left,
      top: canvasEl == null ? void 0 : canvasEl.getBoundingClientRect().top
    };
    return position;
  };

  _proto._set = function _set(key, value) {
    if (key === 'keyValues') {
      var keyValues = value ? value : [];

      if (value.length > 0) {
        this.keyValues = keyValues;
      } else {
        return _fabric$Rect.prototype._set.call(this, key, this.keyValues);
      }
    }

    return _fabric$Rect.prototype._set.call(this, key, value);
  };

  _proto.initialize = function initialize(options) {
    var _this = this;

    this.keyValues = options.keyValues;

    if (options.keyValues.length < 1) {
      this.keyValues = options.keys.map(function (key) {
        return {
          key: '{{' + key + '}}',
          value: ''
        };
      });
    }

    _fabric$Rect.prototype.initialize.call(this, _extends({}, options, {
      strokeWidth: 0,
      fill: '#ecf0f1'
    }));

    this.on('added', function () {
      _this.canvas.on('mouse:move', function (e) {
        if (e.target === _this) {
          var pointer = _this.canvas.getPointer(e.e, false);

          var centerPoint = _this.getCenterPoint();

          var keyScale = _this.getKeyScaling();

          var change = 25 * keyScale;

          if (pointer.x >= centerPoint.x - change && pointer.x <= centerPoint.x + change && pointer.y >= centerPoint.y - change && pointer.y <= centerPoint.y + change) {
            _this.hoverCursor = 'pointer';
          } else {
            _this.hoverCursor = 'default';
          }
        }
      });
    });
    this.on('mouseup', function () {
      if (_this.hoverCursor === 'pointer') {
        var canvasPosition = _this.getCanvasBoundingClientRect();

        _this.setCoords();

        var zoom = _this.canvas.getZoom();

        var scaleX = _this.scaleX,
            scaleY = _this.scaleY,
            width = _this.width,
            height = _this.height;

        var boundingRect = _this.getBoundingRect(false);

        var padLeft = (width * scaleX * zoom - width) / 2;
        var padTop = (height * scaleY * zoom - height) / 2;
        var eventData = {
          object: _this,
          isEditing: true,
          visible: true,
          position: {
            left: canvasPosition.left + boundingRect.left + padLeft + boundingRect.width / 2,
            top: canvasPosition.top + boundingRect.top + padTop + boundingRect.height / 2
          },
          key: _this.keyValues[0]
        };

        _this.canvas.fire('text:key:selected', eventData);
      }
    });
    return this;
  };

  _proto._renderStroke = function _renderStroke(ctx) {
    var keyScale = this.getKeyScaling();
    var path = imagePath;
    ctx.save(); // @ts-ignore

    ctx.scale(1 / this.scaleX, 1 / this.scaleY);
    ctx.scale(keyScale, keyScale);
    ctx.translate(-25.5, -25.5);
    ctx.fillStyle = '#000000';
    var icon = new Path2D(path);
    ctx.fill(icon);
    ctx.restore();
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return fabric.fabric.util.object.extend(_fabric$Rect.prototype.toObject.call(this, propertiesToInclude), {
      keys: this.keyValues.map(function (param) {
        return param.key.substring(2, param.key.length - 2);
      })
    });
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return fabric.fabric.util.object.extend(_fabric$Rect.prototype.toObject.call(this, propertiesToInclude), {
      keys: this.keyValues.map(function (param) {
        return param.key.substring(2, param.key.length - 2);
      })
    });
  };

  DynamicImageObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.DynamicImage(options));
  };

  return DynamicImageObject;
}(fabric.fabric.Rect);
DynamicImageObject.type = 'DynamicImage';
fabric.fabric.DynamicImage = /*#__PURE__*/fabric.fabric.util.createClass(DynamicImageObject, {
  type: DynamicImageObject.type
});
fabric.fabric.DynamicImage.fromObject = DynamicImageObject.fromObject;

var BackgroundObject = /*#__PURE__*/function (_fabric$Rect) {
  _inheritsLoose(BackgroundObject, _fabric$Rect);

  function BackgroundObject() {
    return _fabric$Rect.apply(this, arguments) || this;
  }

  var _proto = BackgroundObject.prototype;

  _proto.initialize = function initialize(options) {
    _fabric$Rect.prototype.initialize.call(this, _extends({}, options, {
      selectable: false,
      hasControls: true,
      hasBorders: false,
      lockMovementY: true,
      lockMovementX: true,
      strokeWidth: 0,
      evented: true,
      hoverCursor: 'default'
    }));

    return this;
  };

  _proto.toObject = function toObject(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Rect.prototype.toObject.call(this, propertiesToInclude);
  };

  _proto.toJSON = function toJSON(propertiesToInclude) {
    if (propertiesToInclude === void 0) {
      propertiesToInclude = [];
    }

    return _fabric$Rect.prototype.toObject.call(this, propertiesToInclude);
  };

  BackgroundObject.fromObject = function fromObject(options, callback) {
    return callback && callback(new fabric.fabric.Background(options));
  };

  return BackgroundObject;
}(fabric.fabric.Rect);
BackgroundObject.type = 'Background';
fabric.fabric.Background = /*#__PURE__*/fabric.fabric.util.createClass(BackgroundObject, {
  type: BackgroundObject.type
});
fabric.fabric.Background.fromObject = BackgroundObject.fromObject;

function Canvas(_ref) {
  var config = _ref.config;
  var containerRef = React.useRef(null);
  var context = React.useContext(EditorContext);
  var setEditor = context.setEditor;
  React.useEffect(function () {
    var editorConfig = Object.assign(defaultEditorConfig, config);
    var container = containerRef.current;
    var clientHeight = container.clientHeight,
        clientWidth = container.clientWidth;
    var canvas = new fabric.fabric.Canvas('canvas', {
      backgroundColor: '#f6f7f9',
      height: clientHeight,
      width: clientWidth,
      preserveObjectStacking: true,
      fireRightClick: true
    });
    var editor = new Editor({
      canvas: canvas,
      context: context,
      config: editorConfig
    });
    setEditor(editor);
    context.setCanvas(canvas);
    var resizeObserver = new ResizeObserver(function (entries) {
      var _ref2 = entries[0] && entries[0].contentRect || {},
          _ref2$width = _ref2.width,
          width = _ref2$width === void 0 ? clientWidth : _ref2$width,
          _ref2$height = _ref2.height,
          height = _ref2$height === void 0 ? clientHeight : _ref2$height;

      editor.canvas.resize(width, height);
    });
    resizeObserver.observe(container);
    return function () {
      editor.destroy();

      if (container) {
        resizeObserver.unobserve(container);
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return React__default.createElement("div", {
    id: "scenify-editor-container",
    ref: containerRef,
    style: {
      flex: 1,
      position: 'relative',
      overflow: 'hidden'
    }
  }, React__default.createElement("div", {
    style: {
      position: 'absolute',
      height: '100%',
      width: '100%'
    }
  }, React__default.createElement("canvas", {
    id: "canvas"
  })));
}

function useEditorContext() {
  var _useContext = React.useContext(EditorContext),
      setCanvas = _useContext.setCanvas,
      canvas = _useContext.canvas,
      activeObject = _useContext.activeObject,
      setActiveObject = _useContext.setActiveObject,
      zoomRatio = _useContext.zoomRatio;

  return {
    setCanvas: setCanvas,
    canvas: canvas,
    activeObject: activeObject,
    setActiveObject: setActiveObject,
    zoomRatio: zoomRatio
  };
}

function useHandlers() {
  var _useContext = React.useContext(EditorContext),
      editor = _useContext.editor;

  return editor;
}

function useActiveObject() {
  var _useContext = React.useContext(EditorContext),
      activeObject = _useContext.activeObject;

  return activeObject;
}

function useEditor() {
  var _useContext = React.useContext(EditorContext),
      editor = _useContext.editor;

  return editor;
}

function useContextMenuRequest() {
  var _useContext = React.useContext(EditorContext),
      contextMenuRequest = _useContext.contextMenuRequest;

  return contextMenuRequest;
}

exports.EditorContext = EditorContext;
exports.EditorProvider = EditorProvider;
exports.default = Canvas;
exports.useActiveObject = useActiveObject;
exports.useContextMenuRequest = useContextMenuRequest;
exports.useEditor = useEditor;
exports.useEditorContext = useEditorContext;
exports.useHandlers = useHandlers;
//# sourceMappingURL=sdk.cjs.development.js.map
